* Unbanked SAS programs (see README_SAS.txt);
* by Mark Kutzbach;
* All SAS programs are run be executing this file;
* See the select modules macros below to indicate the set of modules that should run, in order;
* =1 indicates to run the module;
* =0 indicates to not run;
* two of modules should be run twice, on their own, to load properly;
* so run in this order (check for errors, may see File LIBRARY.FORMATS.CATALOG was created for a different operating system.);
* module_read_fdic (twice);
* module_read_ju10 module_read_ju11;
* module_vars_fdic;
* module_vars_ju10 module_vars_ju11;
* module_summ_ju10 module_summ_ju11;
* after executing all the SAS modules, see README_Stata.txt for estimation code;

*SETTING LIBRARY NAMES;
%let project=unbanked;
%let vintage=&project._26;

*PROGRAMS CAN BE FOUND IN;
%let dirvint=C:\Users\mkutzbach\OneDrive - Federal Deposit Insurance Corporation\Documents\Research\Unbanked\vintages\&vintage.;

*DATA CAN BE FOUND IN;
%let dirdata=C:\Users\mkutzbach\OneDrive - Federal Deposit Insurance Corporation\Documents\Research\Unbanked\data;

*LOG;
proc printto
    log=    "&dirvint.\ctrl_&project..log" new
    print=  "&dirvint.\ctrl_&project..lst" new;
run;

/* select modules -------------------------------------------------------------- */
%let module_read_fdic=0; * Read in Unbanked (run twice);
%let module_read_ju10=0; * Read in IPUMS; * FDIC is in 2nd year of CPS, starts in June 2010 (ju10);
%let module_read_ju11=0; * Read in IPUMS; * FDIC is in 1st year of CPS, starts in June 2011 (ju11);
%let module_vars_fdic=0; * Create variables FDIC unbanked file;
%let module_vars_ju10=0; * Create variables and link to unbanked;
%let module_vars_ju11=0; * Create variables and link to unbanked;
%let module_summ_ju10=1; * Summarize;
%let module_summ_ju11=1; * Summarize;

/* define libraries -------------------------------------------------------------- */

*LIBNAMES;
libname DATAWORK "&dirvint.";
libname UNBANKED "&dirdata.\FDICunbanked\hhmultiyear";
libname IPUMMAMJ "&dirdata.\IPUMS\MAMJ_8_MAMJ" access=readonly;

/* macro values ------------------------------------------------------------------ */
options mprint mlogic symbolgen spool formchar="|----|+|---" compress=no;
* may need to turn this off the first time run;
options fmtsearch=(DATAWORK.catalog);
* for testing;
%let obsuse=max;
* not working yet, see include below;
filename autom "&dirvint.\macros";

* ju10 months for FDIC 2011, 2013, 2015, 2017, 2019 in June;
* if adding a new survey year, copy two years previous, update year+1 and update series+1;
data months_ju10;
   input year month seq series;
   datalines;
   2010  3  1  1
   2010  4  2  1
   2010  5  3  1
   2010  6  4  1
   2010  7  5  1
   2010  8  6  1
   2010  9  7  1
   2011  3  8  1
   2011  4  9  1
   2011  5 10  1
   2011  6 11  1
   2011  7 12  1
   2011  8 13  1
   2011  9 14  1
   2012  3  1  2
   2012  4  2  2
   2012  5  3  2
   2012  6  4  2
   2012  7  5  2
   2012  8  6  2
   2012  9  7  2
   2013  3  8  2
   2013  4  9  2
   2013  5 10  2
   2013  6 11  2
   2013  7 12  2
   2013  8 13  2
   2013  9 14  2
   2014  3  1  3
   2014  4  2  3
   2014  5  3  3
   2014  6  4  3
   2014  7  5  3
   2014  8  6  3
   2014  9  7  3
   2015  3  8  3
   2015  4  9  3
   2015  5 10  3
   2015  6 11  3
   2015  7 12  3
   2015  8 13  3
   2015  9 14  3
   2016  3  1  4
   2016  4  2  4
   2016  5  3  4
   2016  6  4  4
   2016  7  5  4
   2016  8  6  4
   2016  9  7  4
   2017  3  8  4
   2017  4  9  4
   2017  5 10  4
   2017  6 11  4
   2017  7 12  4
   2017  8 13  4
   2017  9 14  4
   2018  3  1  5
   2018  4  2  5
   2018  5  3  5
   2018  6  4  5
   2018  7  5  5
   2018  8  6  5
   2018  9  7  5
   2019  3  8  5
   2019  4  9  5
   2019  5 10  5
   2019  6 11  5
   2019  7 12  5
   2019  8 13  5
   2019  9 14  5
;
run;

* ju11 months for FDIC 2011, 2013, 2015, 2017, 2019 in June;
* if adding a new survey year, copy two years previous, update year+1 and update series+1;
data months_ju11;
   input year month seq series;
   datalines;
   2011  3  1  1
   2011  4  2  1
   2011  5  3  1
   2011  6  4  1
   2011  7  5  1
   2011  8  6  1
   2011  9  7  1
   2012  3  8  1
   2012  4  9  1
   2012  5 10  1
   2012  6 11  1
   2012  7 12  1
   2012  8 13  1
   2012  9 14  1
   2013  3  1  2
   2013  4  2  2
   2013  5  3  2
   2013  6  4  2
   2013  7  5  2
   2013  8  6  2
   2013  9  7  2
   2014  3  8  2
   2014  4  9  2
   2014  5 10  2
   2014  6 11  2
   2014  7 12  2
   2014  8 13  2
   2014  9 14  2
   2015  3  1  3
   2015  4  2  3
   2015  5  3  3
   2015  6  4  3
   2015  7  5  3
   2015  8  6  3
   2015  9  7  3
   2016  3  8  3
   2016  4  9  3
   2016  5 10  3
   2016  6 11  3
   2016  7 12  3
   2016  8 13  3
   2016  9 14  3
   2017  3  1  4
   2017  4  2  4
   2017  5  3  4
   2017  6  4  4
   2017  7  5  4
   2017  8  6  4
   2017  9  7  4
   2018  3  8  4
   2018  4  9  4
   2018  5 10  4
   2018  6 11  4
   2018  7 12  4
   2018  8 13  4
   2018  9 14  4
   2019  3  1  5
   2019  4  2  5
   2019  5  3  5
   2019  6  4  5
   2019  7  5  5
   2019  8  6  5
   2019  9  7  5
   2020  3  8  5
   2020  4  9  5
   2020  5 10  5
   2020  6 11  5
   2020  7 12  5
   2020  8 13  5
   2020  9 14  5
;
run;

* list of CPS basic variables to widen (see read.sas and vars.sas);
%let basicwide=empstat whyunemp faminc;

* list of CPS basic, first month only (see read.sas and vars.sas);
%let basicfirstp=age sex race marst bpl citizen hispan educ labforce occ ind
				 classwkr uhrsworkt uhrswork1 uhrswork2 wkstat multjob empsame ftype famrel;
%let basicfirsth=numprec metro hhtenure statefip county metarea metfips region cbsasz gqtype nfams;

* list of ASEC variables to keep, first instance only (see read.sas and vars.sas);
%let asecfirst=ftotval inctot incwage offpov verify;

* list of FDIC unbanked variables (present in all years unless noted) for ju10 (see vars.sas);
%let fdicuse_ju10=hryear4 hrhhid hrhhid2 hbaseresp hbankstatv2 hunbnk hbnkprevly hbnkprev
						/* hbnkfutr hhincome2 hbnktyp hsmphone*/
                        /* 2015-2017 finances over 12 months */
                        hbilldq hcred12cc hsav12 hsav12typ1 hsav12typ2
                        hcred12newapp hcred12denied hcred12deniedc hcred12discour
                        /* 2011-2017 AFS over 12 months, huse12AFSC huse12atl huse12pp (not 2011) */
                        huse12AFSC huse12AFST huse12afsnbr huse2afstype
                        huse12cc huse12mo huse12pdl huse12pwn huse12ral huse12rto huse12atl huse12rm huse12pp
                        /* 2011 2013 AFS over 30 days */
                        /*huse3AFSCv2 huse3AFSTv2 huseral
                        huse3cc huse3mo huse3pdl huse3pwn huse3rto huse3atl huse3rm huse3pp*/
                        /* Main reason unbanked 2011, 2013, 2015, 2017 */
                        hunbnkrm hunbnkrmv2 hunbnkrmv3
                        /* Main reason: AFS 2011, Prepaid 2013 */
                        huseafscrsnv2 husepprm
                        /* Event: 2013 */
                        hevent1 hevent2 hevent3 hevent4 hevent5 hevent6 hevent7
						/* 2013-2017 Length of bank account ownership, 1 last 12 months, 2 prior to past 12 months */
						hbnknew
                        ;
* list of FDIC unbanked variables (present in all years unless noted) for ju11 (see vars.sas);
%let fdicuse_ju11=hryear4 hrhhid hrhhid2 hbaseresp hbankstatv2 hunbnk hbnkprevly hbnkprev
						/* hbnkfutr hhincome2 hbnktyp hsmphone*/
                        /* 2015-2017 finances over 12 months */
                        hbilldq hcred12cc hsav12 hsav12typ1 hsav12typ2
                        hcred12newapp hcred12denied hcred12deniedc hcred12discour
                        /* 2011-2017 AFS over 12 months, huse12AFSC huse12atl huse12pp (not 2011) */
                        huse12AFSC huse12AFST huse12afsnbr huse2afstype
                        huse12cc huse12mo huse12pdl huse12pwn huse12ral huse12rto huse12atl huse12rm huse12pp
                        /* 2011 2013 AFS over 30 days */
                        /*huse3AFSCv2 huse3AFSTv2 huseral
                        huse3cc huse3mo huse3pdl huse3pwn huse3rto huse3atl huse3rm huse3pp*/
                        /* Main reason unbanked 2011, 2013, 2015, 2017 */
                        hunbnkrm hunbnkrmv2 hunbnkrmv3
                        /* Main reason: AFS 2011, Prepaid 2013 */
                        huseafscrsnv2 husepprm
                        /* Event: 2013 */
                        hevent1 hevent2 hevent3 hevent4 hevent5 hevent6 hevent7
						/* 2013-2017 Length of bank account ownership, 1 last 12 months, 2 prior to past 12 months */
						hbnknew
                        ;

* rename original (see vars.sas);
%let fdicorig_ju10=hrhhid hrhhid2 hbankstatv2;
%let fdicorig_ju11=hrhhid hrhhid2 hbankstatv2;

* rename new (see vars.sas);
%let fdicnew_ju10=hrhhid_num hrhhid2_num hbankstat_any;
%let fdicnew_ju11=hrhhid_num hrhhid2_num hbankstat_any;

/* overall macro -------------------------------------------------------------- */
%macro unbanked;

* macros;
%include "&dirvint.\macros\recode.sas";

/* evaluate if module should be run, execute, and output log and list files ---- */
%macro runmac(val,modnum,modname);
%put module &modname.;
%if (&val.=1) %then %do;
proc printto
    log=    "&dirvint.\loglst\module_&modnum._&modname..log" new
    print=  "&dirvint.\loglst\module_&modnum._&modname..lst" new;
run;
%include "&dirvint.\module_&modnum._&modname..sas";
%run_&modname.;
proc printto
    log=    "&dirvint.\ctrl_&project..log"
    print=  "&dirvint.\ctrl_&project..lst";
run;
%end;
%mend runmac;

/* check each module to see if it should be run --------------------------------- */

%runmac(&module_read_fdic.,01,read_fdic);
%runmac(&module_read_ju10.,01,read_ju10);
%runmac(&module_read_ju11.,01,read_ju11);
%runmac(&module_vars_fdic.,02,vars_fdic);
%runmac(&module_vars_ju10.,02,vars_ju10);
%runmac(&module_vars_ju11.,02,vars_ju11);
%runmac(&module_summ_ju10.,03,summ_ju10);
%runmac(&module_summ_ju11.,03,summ_ju11);

*END OF MACRO TO RUN PROGRAMS;
%mend unbanked;

*RUN PROGRAMS;
%unbanked;
