/*********************************************************************************************
	MACRO NAME: summ
	PURPOSE: Summarize and export CSV for use in Stata
*********************************************************************************************/

* BEGIN MACRO CODE;
%macro macro_summ_pattern;

* years in sample;
proc freq data=DATAWORK.person_&samp. (where=(hasipums=1));
	title "Years in sample";
	table yfdic*start_year / missing;
run;

* create any variables for evaluation;
data person (drop=m);
	set DATAWORK.person_&samp. (where=(hasipums=1));
	* IPUMS perfect basic;
	if (mbasic='11111111') then pattern_basic=1;
	* perfect start, then 5;
	else if (substr(mbasic,1,4)='1111'
		and substr(mbasic,5,1)='1'
		) then pattern_basic=2;
	* perfect start;
	else if (substr(mbasic,1,4)='1111'
		) then pattern_basic=3;
	* some early, some late;
	else if (substr(mbasic,1,1)='1' and (substr(mbasic,2,1)='1' | substr(mbasic,3,1)='1' | substr(mbasic,4,1)='1')
		and substr(mbasic,5,1)='1'
		) then pattern_basic=4;
	* some early;
	else if (substr(mbasic,1,1)='1' and (substr(mbasic,2,1)='1' | substr(mbasic,3,1)='1' | substr(mbasic,4,1)='1')
		) then pattern_basic=5;
	* only first;
	else if (substr(mbasic,1,1)='1'
		) then pattern_basic=6;
	* No basic;
	else if (mbasic ne '') then pattern_basic=7;
	else pattern_basic=8;
	* IPUMS both ASEC;
	if (seq_asec="&perfect_seq_asec.") then pattern_asec=1;
	* first ASEC;
	else if (substr(seq_asec,1,%eval(%length(&perfect_seq_asec.)/2))=substr("&perfect_seq_asec.",1,%eval(%length(&perfect_seq_asec.)/2))) then pattern_asec=2;
	* second ASEC;
	else if (substr(seq_asec,%eval(1+%length(&perfect_seq_asec.)/2),%eval(%length(&perfect_seq_asec.)/2))=substr("&perfect_seq_asec.",1,%eval(%length(&perfect_seq_asec.)/2))) then pattern_asec=3;
	* No ASEC;
	else if (seq_asec ne '') then pattern_asec=4;
	else pattern_asec=5;
	* for tabs;
	one=1;
	* work pattern, from start;
	workdrop=0;
	array _empstatecode(1:8) empstatcode_m1-empstatcode_m8;
	do m=1 to 4;
		if (workdrop=m-1 and _empstatecode(m)=1) then workdrop=m;
	end; 
	* involuntary unemp;
	if (whyunempcode_m2=1 or whyunempcode_m3=1 or whyunempcode_m4=1) then whyunempcode_midmax=1;
	else if (whyunempcode_m2=2 or whyunempcode_m3=2 or whyunempcode_m4=2) then whyunempcode_midmax=2;
	else whyunempcode_midmax=0;
	label whyunempcode_midmax="Worst case for why unemployed - ever involuntary";
	* employed, unemployed, or NILF;
	if (empstatcode_midmax=1) then employ_midmax=1;
	else if (empstatcode_midmax=2 and whyunempcode_midmax>=1) then employ_midmax=2;
	else if (empstatcode_midmax=2 and whyunempcode_midmax=0) then employ_midmax=3;
	else employ_midmax=4;
	* Reason unbanked;
	hunbnkrmv_all=0;
	if (yfdic=2011) then do;
		* problem;
		if (hunbnkrm=2 or hunbnkrm=1) then hunbnkrmv_all=1;
		* minimum;
		if (hunbnkrm=7) then hunbnkrmv_all=2;
		* fees;
		if (hunbnkrm=4) then hunbnkrmv_all=3;
		* missing, unknown;
		if (hunbnkrm in(-1,99)) then hunbnkrmv_all=hunbnkrm;
	end;
	if (yfdic=2013) then do;
		* problem;
		if (hunbnkrmv2=7) then hunbnkrmv_all=1;
		* minimum;
		if (hunbnkrmv2=5) then hunbnkrmv_all=2;
		* fees;
		if (hunbnkrmv2=2) then hunbnkrmv_all=3;
		* missing, unknown;
		if (hunbnkrmv2 in(-1,99)) then hunbnkrmv_all=hunbnkrmv2;
	end;
	if (yfdic=2015 or yfdic=2017 or yfdic=2019) then do;
		* problem;
		if (hunbnkrmv3=9) then hunbnkrmv_all=1;
		* minimum;
		if (hunbnkrmv3=7) then hunbnkrmv_all=2;
		* fees;
		if (hunbnkrmv3=3 or hunbnkrmv3=4) then hunbnkrmv_all=3;
		* missing, unknown;
		if (hunbnkrmv3 in(-1,99)) then hunbnkrmv_all=hunbnkrmv3;
	end;
	label hunbnkrmv_all="Reason unbanked";
	* household events;
	huseafscrsn_all=0;
	if (yfdic=2011) then do;
		* lost income;
		if (huseafscrsnv2=1) then huseafscrsn_all=1;
		* missing, unknown;
		if (huseafscrsnv2 in(-1,99)) then huseafscrsn_all=huseafscrsnv2;
	end;
	label huseafscrsn_all="Reason for using AFS in 2011";
	* household event in last 12 months, only 2013;
	hevent=0;
	if (yfdic=2013) then do;
		* loss income, loss job;
		if (hevent1=1 or hevent3=1) then hevent=1;
		* rise income, new job;
		else if (hevent2=1 or hevent4=1) then hevent=2;
		* retirement, increase expense;
		else if (hevent5=1 or hevent6=1) then hevent=3;
	end;
	label hevent="Household event in 2013";
	* check geography for completeness;
	if (county>0) then hascounty=1;
	else hascounty=0;
	if (metfips=99999 or metfips=.) then hasmetfips=0;
	else if (metfips=99998) then hasmetfips=1;
	else if (metfips>0) then hasmetfips=2;
run;
* create unique household identifier, hh2unum, for use in Stata;
proc sort data=person;
	by hh2unique;
run;
data person;
	retain hh2unum;
	set person;
	by hh2unique;
	if first.hh2unique then hh2unum=max(1,hh2unum+1);
run;

* geography;
proc freq data=person;
	title "geography completeness";
	table hascounty*hasmetfips statefip*hasmetfips /missing;
run; 

* evaluate response;
proc freq data=person;
	title "Response patterns";
	table start_mish*pattern_basic start_mish*faminc_first_m series*hasipums*hasfdic hasfdic*hasfdicresp 
		pattern_basic pattern_asec hasfdic*pattern_basic hasfdicresp*pattern_basic hasfdicresp*pattern_basic*empstatcode_m1 /missing;
	format pattern_basic pattern_basic_&samprecode..;
	format pattern_asec pattern_asec_&samprecode..;
	format empstatcode_m1 empstatcoded.;
run;

* weights;
proc means data=person n mean min max sum;
	title "Weights, all obs";
    var start_wtfinl start_hwtfinl;
run;
proc means data=person (where=(pattern_basic<=3 and hasfdicresp=1 and hhnumemp_m1 ge 1)) n mean min max sum;
	title "Weights, extract sample";
    var start_wtfinl start_hwtfinl;
run;
proc means data=person (where=(pattern_basic<=3 and hasfdicresp=1 and hhnumemp_m1 ge 1 and pernum=1)) n mean min max sum;
	title "Weights, extract sample, householdsish";
    var start_wtfinl start_hwtfinl;
run;

* summary stats;
proc means data=person (where=(pattern_basic<=3 and hasfdicresp=1));
	title "Summary stats";
	var age wkswork2 ftotval inctot incwage;
run;
proc freq data=person (where=(pattern_basic<=3 and hasfdicresp=1));
	title "Summary stats, check";
	table educ /*occ ind classwkr wkstat*/
		/*numprec metro hhtenure offpov verify*/ /missing;
run;

* simple employment patterns;
proc freq data=person (where=(pattern_basic<=3 and hasfdicresp=1));
	title "Employment transition patterns, should be symmetric";
	table empstat_m1 empstatcode_m1 empstatcode_m1*empstatcode_m2 empstatcode_m1*empstatcode_midmax workdrop /missing;
	format empstatcode_m1 empstatcoded.;
	format empstatcode_m2 empstatcoded.;
	format empstatcode_midmax empstatcoded.;
	format workdrop workdropcoded.;
run;
proc freq data=person (where=(pattern_basic<=3 and hasfdicresp=1));
	title "Summary stats";
	table faminccode_first wkstat age sex race hispan educ marst bpl labforce 
		empstat_m2*whyunemp_m2 empstat_m2 whyunemp_m2 
		empstatcode_m2 whyunempcode_m2 /*occ ind classwkr wkstat*/
		/*numprec metro hhtenure offpov verify*/ /missing;
	format faminccode_first faminccoded.;
	format wkstat wkstatcode.;
	format age agecode.;
	format sex sexcode.;
	format race racecode.;
	format hispan hispancode.;
	format educ educcode.;
	format marst marstcode.;
	format bpl bplcode.;
	format labforce labforcecode.;
run;

* macro for count unique;
%macro countunique(u1,u2,u1name,u2name,restrict,restdesc);
proc sql;
	create table samplerestrictsql as
	select count(distinct &u1.) as &u1name.,
		   count(distinct &u2.) as &u2name.
	from work.person where &restrict.;
quit;
data samplerestrict;
	length restriction $40 description $40 &u1name. 5. &u2name. 5.;
	set samplerestrictsql;
	restriction="&restrict.";
	description="&restdesc.";
run;
proc append base=samplerestrictall data=samplerestrict force;
run;
%mend countunique;

* overall dataset sample restrictions, by person emp;
proc datasets library=WORK;
	delete samplerestrictall;
run;
%countunique(cpsidp,hh2unique,persons,households,one eq 1,%str(Civ. age 17-70 elig. June CPS [20-59]));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 6,%str(Respond to CPS in month 1));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3,%str(Respond to CPS in months 1-4));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdic eq 1,%str(Linked to FDIC supplement));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1,%str(Has FDIC response));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1,%str(Employed in month 1));
%countunique(cpsidp,hh2unum,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1,%str(Employed in month 1, num));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1 and start_seq eq 4,%str(FDIC survey m1));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1 and start_seq eq 3,%str(FDIC survey m2));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1 and start_seq eq 2,%str(FDIC survey m3));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1 and start_seq eq 1,%str(FDIC survey m4));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1 and yfdic eq 2011,%str(2011 survey year));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1 and yfdic eq 2013,%str(2013 survey year));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1 and yfdic eq 2015,%str(2015 survey year));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1 and yfdic eq 2017,%str(2017 survey year));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and empstatcode_m1 eq 1 and yfdic eq 2019,%str(2019 survey year));
proc print data=samplerestrictall (keep=description persons households);
	title "TABLE 1: Definition of sample, by numbers of persons and households, person emp";
run;

proc summary data=person (where=(pattern_basic<=3 and hasfdicresp=1 and empstatcode_m1=1)) nway;
	class hh2unique;
	var one;
	output out=hhu n(one)=;
run;
proc contents data=hhu;
run;

* overall dataset sample restrictions, by hh emp;
proc datasets library=WORK;
	delete samplerestrictall;
run;
%countunique(cpsidp,hh2unique,persons,households,one eq 1,%str(Civ. age 17-70 elig. June CPS [20-59]));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 6,%str(Respond to CPS in month 1));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3,%str(Respond to CPS in months 1-4));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdic eq 1,%str(Linked to FDIC supplement));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1,%str(Has FDIC response));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1,%str(Employed in month 1));
%countunique(cpsidp,hh2unum,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1,%str(Employed in month 1, num));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1 and start_seq eq 4,%str(FDIC survey m1));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1 and start_seq eq 3,%str(FDIC survey m2));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1 and start_seq eq 2,%str(FDIC survey m3));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1 and start_seq eq 1,%str(FDIC survey m4));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1 and yfdic eq 2011,%str(2011 survey year));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1 and yfdic eq 2013,%str(2013 survey year));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1 and yfdic eq 2015,%str(2015 survey year));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1 and yfdic eq 2017,%str(2017 survey year));
%countunique(cpsidp,hh2unique,persons,households,pattern_basic le 3 and hasfdicresp eq 1 and hhnumemp_m1 ge 1 and yfdic eq 2019,%str(2019 survey year));
proc print data=samplerestrictall (keep=description persons households);
	title "TABLE 2: Definition of sample, by numbers of persons and households, hh emp";
run;


*END MACRO CODE;
%mend macro_summ_pattern;

* BEGIN MACRO CODE;
%macro macro_summ_emp;

* sample size by year;
proc freq data=person (where=(pattern_basic<=3 and hasfdicresp=1 and empstatcode_m1=1));
	title "Job holders sample, by year";
	table yfdic /missing;
run;

* Split out by job loss;
proc freq data=person (where=(pattern_basic<=3 and hasfdicresp=1 and empstatcode_m1=1));
	title "Summary stats, employed in month 1, by whether lost job";
	table faminccode_first*empstatcode_m2 wkstat*empstatcode_m2 age*empstatcode_m2 sex*empstatcode_m2 race*empstatcode_m2 hispan*empstatcode_m2
		educ*empstatcode_m2 marst*empstatcode_m2 bpl*empstatcode_m2
		/missing nofreq nopct norow;
	format empstatcode_m2 empstatcoded.;
	format faminccode_first faminccoded.;
	format wkstat wkstatcode.;
	format age agecode.;
	format sex sexcode.;
	format race racecode.;
	format hispan hispancode.;
	format educ educcode.;
	format marst marstcode.;
	format bpl bplcode.;
run;
PROC TABULATE DATA=person 
		(where=(pattern_basic<=3 and hasfdicresp=1 and empstatcode_m1=1 and employ_midmax in(1,2,3)))
		FORMAT=COMMA11.0 noseps;
	  title "Summary Stats, Unemployed vs. Employed/NILF";
	  VAR one;
      CLASS empstatcode_m2 
			faminccode_first wkstat age sex race hispan educ marst;
      TABLE faminccode_first wkstat age sex race hispan educ marst, /*all*/ empstatcode_m2*one*(/*n*/ colpctsum) / RTS=18 indent=4;
	format empstatcode_m2 empstatcoded.;
	format faminccode_first faminccoded.;
	format wkstat wkstatcode.;
	format age agecode.;
	format sex sexcode.;
	format race racecode.;
  	format hispan hispancode.;
	format educ educcode.;
	format marst marstcode.;
RUN;

* detailed employment questions;
PROC TABULATE DATA=person (where=(pattern_basic<=3 and hasfdicresp=1 and empstatcode_m1=1)) FORMAT=COMMA11.0;
	  title "Those initially employed, Employment pattern";
	  VAR one;
      CLASS empstatcode_m1 empstatcode_m2 empstatcode_m3 empstatcode_m4 start_seq;
      TABLE empstatcode_m1*empstatcode_m2*empstatcode_m3*empstatcode_m4, all start_seq*one*(n colpctsum) / RTS=18;
RUN;
PROC TABULATE DATA=person (where=(pattern_basic<=3 and hasfdicresp=1 and empstatcode_m1=1)) FORMAT=COMMA11.0;
	  title "Those initially employed, Sequences, Employment, Banked";
	  VAR one;
      CLASS start_seq empstatcode_m2 hunbnk;
      TABLE start_seq*empstatcode_m2, all hunbnk*one*(n rowpctsum) / RTS=18;
RUN;
proc summary data=person (where=(pattern_basic<=3 and hasfdicresp=1 and empstatcode_m1=1)) nway;
	class start_seq empstatcode_m2 hunbnk;
	var one;
	output out=personsum (drop=_TYPE_ _FREQ_) sum(one)=peeps;
run;
proc print data=personsum;
	title "Those initially employed, Sequences, Employment, Banked";
run;
proc freq data=person (where=(pattern_basic<=3 and hasfdicresp=1 and empstatcode_m1=1));
	title "Those initially employed, why drop, reason for unemployment";
	table  
		empstatcode_m2*whyunempcode_m2 
		empstatcode_m3*whyunempcode_m3 
		empstatcode_m4*whyunempcode_m4 
		empstatcode_midmax*whyunempcode_midmax
		/missing;
	format empstatcode_m2 empstatcoded.;
	format empstatcode_m3 empstatcoded.;
	format empstatcode_m4 empstatcoded.;
	format empstatcode_midmax empstatcoded.;
	format whyunempcode_m2 whyunempcoded.;
	format whyunempcode_m3 whyunempcoded.;
	format whyunempcode_m4 whyunempcoded.;
	format whyunempcode_midmax whyunempcoded.;
run;

*END MACRO CODE;
%mend macro_summ_emp;

* BEGIN MACRO CODE;
%macro macro_summ_export;
proc contents data=person;
run;

* export for Stata;
proc freq data=person (where=(hasfdicresp=1 and hhnumemp_m1 ge 1));
	title "response patterns of analysis sample";
	table pattern_basic /missing;
run;
proc freq data=person (where=(hasfdicresp=1 and hhnumemp_m1 ge 1 and pernum=1 and empstatcode_m1=1));
	title "response patterns of analysis sample, reference person";
	table pattern_basic /missing;
run;
proc export data=person (where=(pattern_basic<=3 and hasfdicresp=1 and hhnumemp_m1 ge 1))
    outfile="&dirvint./person_&samp..csv"
    dbms=csv
    replace;
run;

*END MACRO CODE;
%mend macro_summ_export;
