/*********************************************************************************************
	MACRO NAME: vars
	PURPOSE: Widen data (obs-month/field) to (obs/month-field) and create variables
*********************************************************************************************/

* BEGIN MACRO CODE;
%macro macro_vars_widen;

* Years included;
proc freq data=DATAWORK.monthly_&samp.;
	title "Years included, before widen";
	table start_year / missing;
run;

* widen basic monthly responses into person level file (CUSTOM);
data ipumsperson (drop=&basicwide. mtime m mish /*year month seq*/ hasbasic hasasec
		%let firstord=1; 
		%do %until("%scan(&basicfirstp.||&basicfirsth.||&asecfirst.,&firstord.)"="");
			%let firstvar=%scan(&basicfirstp.||&basicfirsth.||&asecfirst.,&firstord.);
			&firstvar._temp 
			%let firstord=%eval(&firstord.+1);
		%end;
		);
	length start_seq 5. seq_basic seq_asec $%eval(%length(&perfect_seq_asec.)+1) totali 8. mbasic masec $8 yfdic 8.
		&basicfirstp. &basicfirsth. &asecfirst. 8.
		%let basicord=1;
		%do %until("%scan(&basicwide.,&basicord.)"="");
			%let basicvar=%scan(&basicwide.,&basicord.);
			&basicvar._m1-&basicvar._m8 &basicvar.code_m1-&basicvar.code_m8 8. 
			%let basicord=%eval(&basicord.+1);
		%end;
		;
	retain start_seq seq_basic seq_asec totali 
		&basicfirstp. &basicfirsth. &asecfirst.
		%let basicord=1; 
		%do %until("%scan(&basicwide.,&basicord.)"="");
			%let basicvar=%scan(&basicwide.,&basicord.);
			&basicvar._m1-&basicvar._m8 &basicvar.code_m1-&basicvar.code_m8 
			%let basicord=%eval(&basicord.+1);
		%end;
		;
	* for variables where only the first observation (basic, or rotation 1 ASEC), rename;
	set DATAWORK.monthly_&samp.
		(rename=(
		%let firstord=1; 
		%do %until("%scan(&basicfirstp.||&basicfirsth.||&asecfirst.,&firstord.)"="");
			%let firstvar=%scan(&basicfirstp.||&basicfirsth.||&asecfirst.,&firstord.);
			&firstvar.=&firstvar._temp 
			%let firstord=%eval(&firstord.+1);
		%end;
		));
	by cpsidp;
	* Arrays to be used for widening monthly variables;
	%let basicord=1;
	%do %until("%scan(&basicwide.,&basicord.)"="");
		%let basicvar=%scan(&basicwide.,&basicord.);
		array _&basicvar. {1:8} &basicvar._m1-&basicvar._m8;
		array _&basicvar.code {1:8} &basicvar.code_m1-&basicvar.code_m8;
		%let basicord=%eval(&basicord.+1);
	%end;
	* First in-frame observation for person, reset variables;
	if (first.cpsidp) then do;
		start_seq=start_mtime_adj-mtime+1;
		seq_basic=trim('');
		seq_asec=trim('');
		totali=0;
		* Assign first-only variables to missing;
		%let firstord=1; 
		%do %until("%scan(&basicfirstp.||&basicfirsth.||&asecfirst.,&firstord.)"="");
			%let firstvar=%scan(&basicfirstp.||&basicfirsth.||&asecfirst.,&firstord.);
			&firstvar.=.;
			%let firstord=%eval(&firstord.+1);
		%end;
		* Assign CPS basic monthly to missing;
		do m=1 to 8;
		%let basicord=1; 
		%do %until("%scan(&basicwide.,&basicord.)"="");
			%let basicvar=%scan(&basicwide.,&basicord.);
			_&basicvar.(m)=.;
			_&basicvar.code(m)=.;
			%let basicord=%eval(&basicord.+1);
		%end;
		end;
	end;
	* For each month, add to sequence of responses;
	seq_basic=trim(trim(seq_basic)||trim(put(hasbasic,1.)));
	seq_asec=trim(trim(seq_asec)||trim(put(hasasec,1.)));
	totali=totali+hasbasic;
	* Fill in basic monthly variables at first response;
	if (totali=1 and hasbasic) then do;
		%let firstord=1; 
		%do %until("%scan(&basicfirstp.||&basicfirsth.,&firstord.)"="");
			%let firstvar=%scan(&basicfirstp.||&basicfirsth.,&firstord.);
			&firstvar.=&firstvar._temp;
			%let firstord=%eval(&firstord.+1);
		%end;
	end;
	* Fill in ASEC for first rotation (if any);
	if (mish<5 and hasasec) then do;
		%let firstord=1; 
		%do %until("%scan(&asecfirst.,&firstord.)"="");
			%let firstvar=%scan(&asecfirst.,&firstord.);
			&firstvar.=&firstvar._temp;
			%let firstord=%eval(&firstord.+1);
		%end;
	end;
	* by month-in-sample, fill in wide variable structure;
	if (mish ne .) then do;
		%let basicord=1; 
		%do %until("%scan(&basicwide.,&basicord.)"="");
			%let basicvar=%scan(&basicwide.,&basicord.);
			_&basicvar.(mish)=&basicvar.;
			_&basicvar.code(mish)=input(put(_&basicvar.(mish),&basicvar.code.),1.);
			%let basicord=%eval(&basicord.+1);
		%end;
	end;
	* once all months are processed, finalize variables and output;
	if (last.cpsidp) then do;
		* note that lenghts here are scenario specific and depend on macro;
		seq_basic=substr(seq_basic,2,%eval(%length(&perfect_seq_asec.)));
		seq_asec=substr(seq_asec,2,%eval(%length(&perfect_seq_asec.)));
		length seq_basic seq_asec $%eval(%length(&perfect_seq_asec.));
		mbasic=substr(seq_basic,start_seq,4)||substr(seq_basic,start_seq+%eval(%length(&perfect_seq_asec.)/2),4);
		masec=substr(seq_asec,start_seq,4)||substr(seq_asec,start_seq+%eval(%length(&perfect_seq_asec.)/2),4);
		* specialized variables;
		empstat_midmax=max(_empstat(2),_empstat(3),_empstat(4));
		empstat_endmax=max(_empstat(5),_empstat(6),_empstat(7),_empstat(8));
		empstatcode_midmax=input(put(empstat_midmax,empstatcode.),1.);
		empstatcode_endmax=input(put(empstat_endmax,empstatcode.),1.);
		* impute family income forward, where missing, and record the month used;
		faminc_first=1000;
		faminc_first_m=.;
		do m=1 to 8;
			if (faminc_first>900 and .<_faminc(m)<1000) then do;
				* record when new information was first obtained (ignores repeated zeros);
				if (_faminc(m)<faminc_first) then faminc_first_m=m;
				* record first information;
				faminc_first=_faminc(m);
			end;
		end;
		faminccode_first=input(put(faminc_first,faminccode.),1.);
		* create variable for anticipated FDIC unbanked data year;
		yfdic=scan("&yearfdic.",series);
		* output only last record, one per person;
		output ipumsperson;
	end;
run;

* fix order of variables and sort random for review;
data ipumsperson;
	retain cpsidp start_year start_month start_mish start_mtime start_mtime_adj start_hrhhid start_hrhhid2 start_pernum start_relate rand 
		seq_basic seq_asec totali mbasic masec yfdic;
	set ipumsperson;
run;
proc sort data=ipumsperson;
	by rand;
run;
proc print data=ipumsperson (obs=8);
	title "Review person records";
run;
proc contents data=ipumsperson;
run;
* check variables;
proc freq data=ipumsperson;
	title "First observed";
	table start_seq start_mish totali 
		  empstat_m1-empstat_m8 empstat_midmax faminc_m1 faminc_first faminccode_first /missing;
run;
proc print data=ipumsperson (obs=20 keep=faminc_m1-faminc_m8 faminc_first faminccode_first faminc_first_m
	where=(faminc_m1=.));
	title "Persons that start with no faminc observation";
run;
proc print data=ipumsperson (obs=20 keep=faminc_m1-faminc_m8 faminc_first faminccode_first faminc_first_m
	where=(faminccode_first=0));
	title "Persons that end with faminc non-response";
run;
proc freq data=ipumsperson;
	title "First observed, recoded";
	table empstat_m1*empstatcode_m1 empstatcode_m1*empstatcode_midmax
		faminc_m1*faminc_first_m faminc_first*faminc_first_m /missing;
	format faminc_m1 faminccode.;
	format faminc_first faminccode.;
run;

*END MACRO CODE;
%mend macro_vars_widen;

* BEGIN MACRO CODE;
%macro macro_vars_summ;

* Years included;
proc freq data=ipumsperson;
	title "Years included, after widen";
	table start_year / missing;
run;

* Summarize response sequences, basic;
proc summary data=ipumsperson (where=(start_mish<=4)) nway;
	class seq_basic start_mtime;
	var totali;
	id start_year start_month;
	output out=ipumspersonsum (drop=_FREQ_ _TYPE_) n(totali)=rec;
run;
proc sort data=ipumspersonsum;
	by descending rec start_mtime;
run;
proc print data=ipumspersonsum (obs=25);
	title "Frequency of sequences, basic";
run;
proc print data=ipumsperson (obs=8 where=(mbasic='11111111'));
	title "Examples of perfect, basic";
run;

* summarize response sequences, basic, mish;
proc summary data=ipumsperson (where=(start_mish<=4)) nway;
	class mbasic;
	var totali;
	id start_year start_month;
	output out=ipumspersonsum (drop=_FREQ_ _TYPE_) n(totali)=rec;
run;
proc sort data=ipumspersonsum;
	by descending rec;
run;
proc print data=ipumspersonsum (obs=25);
	title "Frequency of sequences, basic, MISH";
run;

* summarize response sequences, asec (CUSTOM);
proc summary data=ipumsperson (where=(start_mish<=4)) nway;
	class seq_asec start_mtime;
	var totali;
	id start_year start_month;
	output out=ipumspersonsum (drop=_FREQ_ _TYPE_) n(totali)=rec;
run;
proc sort data=ipumspersonsum;
	by descending rec start_mtime;
run;
proc print data=ipumspersonsum (obs=25);
	title "Frequency of sequences, ASEC";
run;
proc print data=ipumsperson (obs=8 where=(seq_asec="&perfect_seq_asec."));
	title "Examples of perfect, ASEC";
run;

* summarize response sequences, basic with asec (CUSTOM);
proc summary data=ipumsperson (where=(start_mish<=4 and seq_asec="&perfect_seq_asec.")) nway;
	class seq_basic start_mtime;
	var totali;
	id start_year start_month;
	output out=ipumspersonsum (drop=_FREQ_ _TYPE_) n(totali)=rec;
run;
proc sort data=ipumspersonsum;
	by descending rec start_mtime;
run;
proc print data=ipumspersonsum (obs=25);
	title "Examples, basic with asec";
run;

* weights;
proc means data=ipumsperson mean min max sum;
	title "Weights, all obs";
    var start_wtfinl start_hwtfinl;
run;
proc means data=ipumsperson (where=(start_mish=1)) mean min max sum;
	title "Weights, start in first MIS";
	var start_wtfinl start_hwtfinl;
run;

* END MACRO CODE;
%mend macro_vars_summ;

* BEGIN MACRO CODE;
%macro macro_vars_hh;

* create list of households as frame;
proc sort data=ipumsperson;
	by yfdic start_hrhhid start_hrhhid2;
run;

* limit sample to persons in prime earning years not approaching retirement;
data ipumsperson;
	set ipumsperson (where=(age>=20 and age<60));
	* create work indicator;
	employed_m1=0;
	if (empstatcode_m1=1) then employed_m1=1;
	employed_m5=0;
	if (empstatcode_m5=1) then employed_m5=1;
run;

* how to deal with multiple persons in household;
* 1) create measures at hrhhidhrhhid2/household/family level (number adults, number working) - disregard housing unit hrhhid;
* 2) in Stata, collapse records to one per household;

* count up adults and employed persons within household and merge back onto file;
proc summary data=ipumsperson nway;
	class yfdic start_hrhhid start_hrhhid2;
	var employed_m1 employed_m5;
	output out=ipumshh2 (drop=_FREQ_ _TYPE_) n(employed_m1)=hhnum_m1 n(employed_m5)=hhnum_m5
											sum(employed_m1)=hhnumemp_m1 sum(employed_m5)=hhnumemp_m5
											;
run;
data ipumsperson;
	merge ipumsperson ipumshh2 /*ipumshh2emp*/;
	by yfdic start_hrhhid start_hrhhid2;
run;

* variables describing household;
proc freq data=ipumsperson;
	title "hh size";
	table hhnum_m1 hhnumemp_m1
		  hhnum_m5 hhnumemp_m5 
		  hhnum_m1*hhnum_m5 
		  hhnumemp_m1*hhnumemp_m5 
			/missing;
run;
proc print data=ipumsperson (obs=25 keep=start_hrhhid start_hrhhid2 yfdic gqtype ftype sex age 
											empstatcode_m1 hhnum_m1 hhnumemp_m1 empstatcode_m5 hhnum_m5 hhnumemp_m5);
	title "examples of hh"
run;

* END MACRO CODE;
%mend macro_vars_hh;

* BEGIN MACRO CODE;
%macro macro_vars_fdic;

* load unbanked, format catalog should be loaded (CUSTOM);
%put vars: fdicuse_&samp.;
data hmultiyear;
	length hrhhid $15 hrhhid2 $5;
	set DATAWORK.hmultiyear (keep=&&fdicuse_&samp.. /*pnum*/ perrp pulineno hhfamtyp where=(hryear4 in (&yearfdic.)) 
		rename=(
		%let renord=1; 
		%do %until("%scan(&&fdicorig_&samp..,&renord.)"="");
			%scan(&&fdicorig_&samp..,&renord.)=%scan(&&fdicnew_&samp..,&renord.)
			%let renord=%eval(&renord.+1);
		%end;
		));
	hrhhid=trim(put(hrhhid_num,$15.));
	hrhhid2=trim(put(hrhhid2_num,$5.));
run;
proc contents data=hmultiyear;
	title "hmultiyear variables";
run;

* check for duplicates, should not be any now that hrhhid2 is added;
proc sort data=hmultiyear nodupkey;
	by hryear4 hrhhid hrhhid2;
run;

* merge with unbanked;
proc sort data=ipumsperson;
	by yfdic start_hrhhid start_hrhhid2;
run;
data ipumsperson;
	merge ipumsperson (in=inipums rename=(start_hrhhid=hrhhid start_hrhhid2=hrhhid2 
			start_pernum=pernum start_lineno=lineno start_uh_relhd_b4=uh_relhd_b4 start_relate=relate))
		  hmultiyear (in=infdic rename=(hryear4=yfdic))
		  ;
	by yfdic hrhhid hrhhid2;
	if (inipums) then hasipums=1;
	else hasipums=0;
	if (infdic) then hasfdic=1;
	else hasfdic=0;
	if (hunbnk in (1,2)) then hasfdicresp=1;
	else hasfdicresp=0;
	hh2unique=cats(put(yfdic,4.),hrhhid,hrhhid2);
	label hh2unique="unique household hrhhid||hrhhid2"
run;
proc freq data=ipumsperson;
	title "Check merging and match rates, note that not all ipums are used for each early/late sample";
	table hasipums*hasfdic hasfdic*hunbnk start_mtime_adj*hasipums /missing;
run;
proc print data=ipumsperson (obs=20 keep=yfdic hrhhid hrhhid2 hh2unique cpsidp pernum pulineno lineno uh_relhd_b4 perrp relate);
	title "Check on agreement of unique ids and technical data (pulineno=lineno and uh_relhd_b4=perrp for reference person)";
run;
proc summary data=ipumsperson (where=(hasipums=1)) nway;
	class yfdic hrhhid hrhhid2;
	var hasipums;
	output out=temp max(hasipums)=one;
run;
proc summary data=temp nway;
	var one;
	output out=yhh sum(one)=unique;
run;
proc print data=yhh;
	title "Check unique ID count (hrhhid hrhhid2)";
run;
proc summary data=ipumsperson (where=(hasipums=1)) nway;
	class hh2unique;
	var hasipums;
	output out=temp max(hasipums)=one;
run;
proc summary data=temp nway;
	var one;
	output out=hh sum(one)=unique;
run;
proc print data=hh;
	title "Check unique ID count (hh2unique)";
run;

* limit to those in IPUMS CPS after restrictions imposed above;
data ipumsperson;
	set ipumsperson;
	if (hasipums=1);
run;

* count unique responses within housing unit;
proc freq data=ipumsperson;
	title "FDIC responses";
	table hasfdicresp /missing;
run;
proc summary data=ipumsperson nway;
	class yfdic hrhhid hrhhid2;
	var hasfdicresp hasfdic;
	output out=hh2sum (drop=_TYPE_ _FREQ_) max(hasfdicresp)=  max(hasfdic)=;
run;
proc summary data=hh2sum nway;
	class yfdic hrhhid;
	var hasfdicresp hasfdic;
	output out=hhsum (drop=_TYPE_ _FREQ_) sum(hasfdicresp)=hasfdicrespsum sum(hasfdic)=hasfdicsum n(hasfdic)=households;
run;
proc freq data=hhsum;
	title "Cases of multiple FDIC responses within housing unit";
	table hasfdicsum*hasfdicrespsum /missing;
run;

* examine multi-household housing units;
proc print data=hhsum (obs=25 where=(hasfdicrespsum>1));
run;
proc sort data=ipumsperson;
	by yfdic hrhhid;
run;
data ipumsperson;
	merge ipumsperson hhsum;
	by yfdic hrhhid;
run;
proc freq data=ipumsperson;
	title "Cases of persons not responding to FDIC when others in housing unit did";
	table hasfdic*hasfdicresp /missing;
run;
proc freq data=ipumsperson (where=(hasfdicrespsum>0));
	title "Cases of persons not responding to FDIC when others in housing unit did (among those that did)";
	table hasfdicrespsum*hasfdicresp households*hasfdicresp /missing;
run;
* drop hhperyr and pnum for 2019;
proc print data=ipumsperson (keep=/*hhperyr*/ hrhhid hrhhid_num hrhhid2 yfdic pernum perrp relate pulineno gqtype ftype hasfdic hunbnk hhfamtyp sex age where=(hrhhid_num=14266503851));
run;
proc print data=ipumsperson (keep=/*hhperyr*/ hrhhid hrhhid_num hrhhid2 yfdic pernum perrp relate pulineno gqtype ftype hasfdic hunbnk hhfamtyp sex age where=(hrhhid_num=110022718274));
run;

* review person number and householder;
proc freq data=ipumsperson (where=(hasfdicresp=1 and pernum=1));
	title "Person records in household, has fdic response, limited to pernum=1";
	table perrp*uh_relhd_b4 pulineno*lineno /missing;
run;
* focus is on households, wait until Stata to impose the following restrictions;
* perrp, from hh file, is:;
*  1 (Reference person living with relatives) or 2 (Reference person living without relatives);
* and relate, from cps basic person file, is:;
*  101 (Head/householder)
* this should encompase 99.86 percent of reference persons, or pernum=1;
* then, focus analysis on characteristics of pernum=1; 

* output wide file (CUSTOM);
data DATAWORK.person_&samp.;
	retain yfdic hh cpsidp;
	set ipumsperson;
run;
proc contents data=DATAWORK.person_&samp. varnum;
	title "Variables of person-level file";
run;

*END MACRO CODE;
%mend macro_vars_fdic;
