* Unbanked plots for Stata, Mark Kutzbach
set more off
set linesize 140

clear
set matsize 800

* set version number and run name
global vnum="26"
global vers="ju11"
global verspost=""

* vintage name
global vint="unbanked_${vnum}"
display "Analysis for Vintage name: ${vint}"

* programs
global projdir="C:\user\documents\Unbanked\vintages\\${vint}"
cd "$projdir"

* program for plotting results with a confidence interval
capture program drop plotci
program define plotci
	* 1: sample
	* 2: model
	* 3: outcome
	* 4: t-statistic
	* 5: corresponding CI level
	* 6: model description
	* 7: outcome description
	* 8: treatment type
	* 9: treatment description
	* 10: title
	* 11: number of interactions and omitted
	* 12: interaction variable and filename
	* Plot with title and subtitle
	serrbar `2'_b_`3' `2'_se_`3' grp if treatment=="`8'", scale (1.96) ///
	title("Effect on `7' status, by `10'") ///
	sub("`5'% C.I., `6', job loss vs. `9' counterfactual") ///
	yline(0) b2(`10') ytitle("") ///
	l1(Estimate) xtitle("") ///
	xlab(1(1)`11') xlabel(, valuelabel)
	graph save plotci_`1'_`2'_`3'_CI`5'_`8'_`12', replace
	graph export "${projdir}\plotci_`1'_`2'_`3'_CI`5'_`8'_`12'.pdf", as(pdf) name("Graph") replace
	graph export "${projdir}\plotci_`1'_`2'_`3'_CI`5'_`8'_`12'.png", as(png) name("Graph") replace
end

* program for plotting results with a confidence interval
capture program drop plotciclean
program define plotciclean
	* 1: sample
	* 2: model
	* 3: outcome
	* 4: t-statistic
	* 5: corresponding CI level
	* 6: model description
	* 7: outcome description
	* 8: treatment type
	* 9: treatment description
	* 10: title
	* 11: number of interactions and omitted
	* 12: interaction variable and filename
	* 13: Y-axis ticks (A(increment)Z)
	* 14: Y-range (A Z) so that both figures use same range
	* Plot clean (no title and subtitle)
	serrbar `2'_b_`3' `2'_se_`3' grp if treatment=="`8'", scale (1.96) ///
	yline(0) b2(`10') ytitle("") ///
	ylabel(`13') yscale(range(`14')) ///
	l1("Estimate") xtitle("") ///
	xlab(1(1)`11') xlabel(, valuelabel)
	graph save plotciclean_`1'_`2'_`3'_CI`5'_`8'_`12', replace
	graph export "${projdir}\plotciclean_`1'_`2'_`3'_CI`5'_`8'_`12'.pdf", as(pdf) name("Graph") replace
	graph export "${projdir}\plotciclean_`1'_`2'_`3'_CI`5'_`8'_`12'.png", as(png) name("Graph") replace
end

* Appendix Figure B2;
* run main program. Copy linear combination (lincom) effects of: Plot Unbanked by Family Income
clear
input str11 treatment byte grp	ols_multi_b_unbank	ols_multi_se_unbank
u_m2_vs_emp	0	0.05   0.01
u_m2_vs_emp	1	0.2028790   0.0528053
u_m2_vs_emp	2	0.0544700   0.0415681
u_m2_vs_emp	3	0.05   0.01
u_m2_vs_m6	0	0.05   0.01
u_m2_vs_m6	1	0.2976127   0.0747089
u_m2_vs_m6	2	0.0714275   0.0697356
u_m2_vs_m6	3	0.05   0.01
end
* label groups
label define faminc 0 "" 1 "$0 - $19,999" 2 "$20,000 - $39,999" 3 ""
label values grp faminc
list

* Note that grp=0 and grp=3 are only so that Stata graph makes proper display of grp=1 and grp=2;
* Go to Start Graph Editor. Unlock all. Right click on extra items (scatter) and (capped spike) select edit observation. 
* Change color to white so not visible on background.

* Plot with title and subtitle
plotci "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_emp" "remain-employed" "family income" "2" "famincpres"
plotci "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_m6" "subsequent job loss" "family income" "2" "famincpres"
* Plot clean (no title and subtitle)
plotciclean "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_emp" "remain-employed" "Family income" "2" "famincpres" "-0.1(0.1)0.5" "-0.11 0.51"
plotciclean "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_m6" "subsequent job loss" "Family income" "2" "famincpres" "-0.1(0.1)0.5" "-0.11 0.51"

* Appendix Figure B3;
* run main program. Copy linear combination (lincom) effects of: Plot Unbanked by Race/Ethnicity;
* Note ORDER OF GRP CHANGED SO THAT LABELS PRINT BETTER;
clear
input str11 treatment byte grp	ols_multi_b_unbank	ols_multi_se_unbank
u_m2_vs_emp	1	0.1673720   0.0708453
u_m2_vs_emp	2	0.0743476   0.0629334
u_m2_vs_emp	3	0.0578947   0.1000177
u_m2_vs_emp	4	0.1520747   0.0529684
u_m2_vs_m6	1	0.4001973   0.0846844
u_m2_vs_m6	2	0.0740108   0.1019259
u_m2_vs_m6	3	0.1110018   0.1092242
u_m2_vs_m6	4	0.1896157   0.0714305
end
* label groups
label define raceth 1 "Black" 2 "Hispanic" 3 "Other race" 4 "White"
label values grp raceth
list

* Plot with title and subtitle
plotci "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_emp" "remain-employed" "race/ethnicity" "4" "raceth"
plotci "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_m6" "subsequent job loss" "race/ethnicity" "4" "raceth"
* Plot clean (no title and subtitle)
plotciclean "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_emp" "remain-employed" "Race/ethnicity" "4" "raceth" "-0.1(0.1)0.6" "-0.16 0.61"
plotciclean "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_m6" "subsequent job loss" "Race/ethnicity" "4" "raceth" "-0.1(0.1)0.6" "-0.16 0.61"

* Appendix Figure B4;
* run main program. Copy linear combination (lincom) effects of: Plot Unbanked by Year;
clear
input str11 treatment byte grp	ols_multi_b_unbank	ols_multi_se_unbank
u_m2_vs_emp	1   .1319414   .0621661
u_m2_vs_emp	2   .1242593   .0718454
u_m2_vs_emp	3   .1604912   .0862466
u_m2_vs_emp	4   .1049993   .0730971
u_m2_vs_emp	5   .0908365   .0882104
u_m2_vs_m6	1  -.0093031   .1480579
u_m2_vs_m6	2   .2498641   .1028259
u_m2_vs_m6	3   .2998236   .1087874
u_m2_vs_m6	4   .2175769   .1875324
u_m2_vs_m6	5   .1657843   .1042170
end
* label groups
label define yfdic 1 "2011" 2 "2013" 3 "2015" 4 "2017" 5 "2019"
label values grp yfdic
list

* Plot with title and subtitle
plotci "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_emp" "remain-employed" "survey year" "5" "yfdic"
plotci "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_m6" "subsequent job loss" "survey year" "5" "yfdic"
* Plot clean (no title and subtitle)
plotciclean "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_emp" "remain-employed" "Survey year" "5" "yfdic" "-0.2(0.2)0.6" "-0.31 0.61"
plotciclean "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_m6" "subsequent job loss" "Survey year" "5" "yfdic" "-0.2(0.2)0.6" "-0.31 0.61"

* Figure 4;
* run main program. Copy linear combination (lincom) effects of: Plot Rotation Group (MIS) start_seq
* note that start_seq of 4 is rotation group 1
* vs_emp
*    Sample N       7466
*     Treat N        245
*   Control N       7221
* vs_m6
*    Sample N        368
*     Treat N        245
*   Control N        123
clear
input str11 treatment byte grp	ols_multi_b_unbank	ols_multi_se_unbank
u_m2_vs_emp	1	0.0402615   0.0512050
u_m2_vs_emp	2	0.0784812   0.0500977
u_m2_vs_emp	3	0.1824141   0.0713673
u_m2_vs_emp	4	0.1369258   0.0560034
u_m2_vs_m6	1	0.0125657   0.1101505
u_m2_vs_m6	2	0.2171889   0.0867294
u_m2_vs_m6	3	0.1704181   0.1262531
u_m2_vs_m6	4	0.1745527   0.0795964
end
* label groups
label define rg 1 "1" 2 "2" 3 "3" 4 "4"
label values grp rg
list

* Plot with title and subtitle
plotci "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_emp" "remain-employed" "Rotation group" "4" "start_seq"
plotci "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_m6" "subsequent job loss" "Rotation group" "4" "start_seq"
* Plot clean (no title and subtitle)
plotciclean "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_emp" "remain-employed" "Rotation group" "4" "start_seq" "-0.2(0.2)0.4" "-0.21 0.41"
plotciclean "${vers}" "ols_multi" "unbank" "1.96" "95" "OLS w. controls" "unbanked" "u_m2_vs_m6" "subsequent job loss" "Rotation group" "4" "start_seq" "-0.2(0.2)0.4" "-0.21 0.41"

* END OF PROGRAMS *;