* Unbanked edits;
* By Mark Kutzbach;
#delimit;

* auxiliary data;

* person-level CPS variables matched with CPS extract by Ryan Goodstein;
* Ryan appended person level files together (11-19);
* merge to person data by hh variables as well as lineno;
* Use qstnum occurnum to determine reference person;
* Usually uses the lowest person number, exclude persons with zero weight (pwsupwgt);
* hsupresp=1, reference person;
* variables are hes2, pes2a, pes2b;
* https://cps.ipums.org/cps-action/variables/group;
* qstnum, 5 digit;
* occurnum, 2 digit;
* pulineno;

* personl-level response data;
global prsndir="${datadir}\prsnlvl";
use "${prsndir}\person_${vers}_merged.dta", clear;
keep if _merge==3;
keep yfdic cpsidp qstnum occurnum hes2 pes2a pes2b pxb30;
sort yfdic cpsidp;
save "$projdir\\prsnlvl_$vers.dta", replace;

* FINRA financial literacy data;
global finradir="${datadir}\FINRA"; 
use "${finradir}\finra_finlit_stateyr.dta", clear;
drop n n_oursmpl;
rename fips2 statefip;
rename year yfdic;
format statefip %8.0g;
format yfdic %8.0g;
sort statefip yfdic;
save "$projdir\\finra_finlit_stateyr.dta", replace;

* BankOn data with SOD;
global bankondir="${datadir}\BankOn"; 
use "${bankondir}\Combined SOD Census Dataset.dta", clear;
rename fips statefip;
rename year yfdic;
format statefip %8.0g;
format yfdic %8.0g;
gen bankonshare=bankonbranches/retailbranches;
gen bankonpercap=bankonbranches/(Population/100000);
sort statefip yfdic;
save "$projdir\\bankon.dta", replace;

* load csv produced from sas processing;
insheet using "$projdir\\$dataset.csv", comma clear;
format cpsidp %15.0f;

* add on person level data;
merge 1:1 yfdic cpsidp using "$projdir\\prsnlvl_${vers}.dta";
keep if _merge==3;
drop _merge;

* summarize;
* describe *;
tab start_year;
tab yfdic;
* sort for consistency;
sort hh2unum pernum;

****** Check input data ******;
rename hhnum_m1 hhnum;
rename hhnumemp_m1 hhnumemp;
tab yfdic;
tab pernum;
tab empstatcode_m1;
tab empstatcode_m2;
tab hhnumemp;
tab hhnumemp empstatcode_m1;

* keep only households with an employed person who satisfies pattern_basic, i.e. no attrition in first year MIS 1-4;
egen hhminemp_m1_v2=min(empstatcode_m1), by(hh2unum);
tab hhnumemp hhminemp_m1_v2;
keep if hhminemp_m1_v2==1;

****** Outcomes ******;

* Unbanked from person level data;
gen hunbankhes2=0;
replace hunbankhes2=1 if hes2==2;
egen hunbankpes2amean=mean(pes2a), by(hh2unum);
gen hunbankpes2a=0;
replace hunbankpes2a=1 if hunbankpes2amean==-1;
* number of bank accounts;
gen binarypes2a=0;
replace binarypes2a=1 if pes2a==1;
egen haccounts=sum(binarypes2a), by(hh2unum);
gen hbankaccts=0;
replace hbankaccts=haccounts if hunbankhes2==0;
* is person unbanked? (from prsnlvl data);
gen unbankpes2a=0 if pes2a==1;
replace unbankpes2a=1 if hunbankpes2amean==-1;
replace unbankpes2a=1 if hes2==2;
replace unbankpes2a=1 if pes2a==0;

* Unbanked;
tab hunbnk;
gen hunbank=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbank=1 if hunbnk=="Unbanked";
tab yfdic hunbank, missing;
tab hunbank hunbankhes2, missing;
tab hunbank hunbankpes2a, missing;
tab hunbank haccounts, missing;
tab hunbank hbankaccts, missing;
tab hunbank unbankpes2a, missing;

* Unbanked always;
tab hbnkprevly hunbnk;
gen hunbankalw=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbankalw=1 if hbnkprevly=="Never had bank account";
tab hunbank hunbankalw, missing;

* Unbanked year plus, but not always;
tab hbnkprevly hunbnk;
gen hunbankyrp=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbankyrp=1 if hbnkprevly=="Had bank account more than 1 year ago";
tab hunbank hunbankyrp, missing;

* Unbanked long term;
gen hunbanklong=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbanklong=1 if hbnkprevly=="Never had bank account" | hbnkprevly=="Had bank account more than 1 year ago";
tab hunbank hunbanklong, missing;

* Unbanked short term (not including Previously banked, recency unknown and Unknown);
gen hunbankshtr=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbankshtr=1 if hbnkprevly=="Had bank account within last year";
tab hunbnk hunbankshtr, missing;

* Newly or recently banked (see FDIC 2017, Table 3.4 Household Banking Status Transitions by Year);
tab hbnknew, missing;
tab hunbank hbnknew, missing;
tab hbnknew yfdic, missing;
gen newbank=0 if inlist(yfdic, 2013, 2015, 2017) & hunbnk=="Has bank account";
replace newbank=1 if newbank==0 & hbnknew=="Became banked in past 12 months"; * or else Banked prior to past 12 months;
tab newbank hunbank if inlist(yfdic, 2013, 2015, 2017), missing;
tab newbank hunbank, missing;

* Reason unbanked, financial;
tab hunbnkrmv_all;
gen hunbank_rfin=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbank_rfin=1 if hunbank==1 & hunbnkrmv_all==1;
replace hunbank_rfin=1 if hunbank==1 & hunbnkrmv_all==2;
replace hunbank_rfin=1 if hunbank==1 & hunbnkrmv_all==3;
tab yfdic hunbank_rfin;

* Reason unbanked, other;
gen hunbank_roth=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbank_roth=1 if hunbank & hunbank_rfin!=1;
tab yfdic hunbank_roth;

* Check totals of unbanke disaggregations;
tab hunbankshtr hunbanklong if hunbank==1;
tab hunbank_rfin hunbank_roth if hunbank==1;
tab hbnkprevly if hunbank==1 & hunbankshtr==0 & hunbanklong==0;

* Prepaid card (12 months);
gen use12pp=0 if inlist(yfdic, 2013, 2015, 2017, 2019);
replace use12pp=1 if huse12pp=="Yes";
tab yfdic use12pp;

* nonbank AFS transaction services;
gen use12mo=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace use12mo=1 if huse12mo=="Yes";
gen use12cc=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace use12cc=1 if huse12cc=="Yes";

* nonbank AFS credit products;
gen use12pw=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace use12pw=1 if huse12pwn=="Yes";
gen use12pd=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace use12pd=1 if huse12pdl=="Yes";

* Unbanked and using nonbank AFS products and services;
gen hunbank1_pp=0 if inlist(yfdic, 2013, 2015, 2017, 2019);
replace hunbank1_pp=1 if hunbank==1 & huse12pp=="Yes";
gen hunbank1_mo=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbank1_mo=1 if hunbank==1 & huse12mo=="Yes";
gen hunbank1_cc=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbank1_cc=1 if hunbank==1 & huse12cc=="Yes";
gen hunbank1_pw=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbank1_pw=1 if hunbank==1 & huse12pwn=="Yes";
gen hunbank1_pd=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace hunbank1_pd=1 if hunbank==1 & huse12pdl=="Yes";

* Reduced earnings;
tab faminc_m1 faminc_m5, missing;
gen famincfall=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace famincfall=1 if faminc_m5<faminc_m1;
tab faminccode_m1 famincfall;

* Increased earnings;
gen famincrise=0 if inlist(yfdic, 2011, 2013, 2015, 2017, 2019);
replace famincrise=1 if faminc_m5>faminc_m1;
tab faminccode_m1 famincrise;

* Event based reduce earnings;
gen eventincfall=0;
replace eventincfall=1 if hevent==1;
replace eventincfall=. if yfdic!=2013;

* Event based increase earnings;
gen eventincrise=0;
replace eventincrise=1 if hevent==2;
replace eventincrise=. if yfdic!=2013;

******** Treatment Variables ********;

* employment history, month 1 is M1 is MIS=1;
gen jobhist="";
gen mtemp="";
forvalues m=1/8 {;
	replace mtemp="-";
	replace mtemp="E" if empstatcode_m`m'==1;
	replace mtemp="N" if empstatcode_m`m'==2;
	replace mtemp="U" if whyunempcode_m`m'>=1 & whyunempcode_m`m'!=.;
	replace jobhist=jobhist+mtemp;
	};
tab jobhist, missing;
tab jobhist if empstatcode_m1==1, missing;

* job loss (mm or midmax identifies the worst status in months 2, 3, and 4);
gen jobloss_0_mm=0;
replace jobloss_0_mm=1 if empstatcode_m1==1 & empstatcode_midmax==2;
tab jobloss_0_mm empstatcode_midmax;

* unemployed with job loss (a more specific treatment);
gen jobloss_u_mm=0;
replace jobloss_u_mm=1 if empstatcode_m1==1 & empstatcode_midmax==2 & whyunempcode_midmax>=1;
table jobloss_u_mm empstatcode_midmax whyunempcode_midmax, contents(freq);

* job loss, M2;
gen jobloss_0_m2=0;
replace jobloss_0_m2=1 if empstatcode_m1==1 & empstatcode_m2==2;
tab jobloss_0_m2 empstatcode_m2;

* unemployed, M2;
gen jobloss_u_m2=0;
replace jobloss_u_m2=1 if empstatcode_m1==1 & empstatcode_m2==2 & whyunempcode_m2>=1;
table jobloss_u_m2 empstatcode_m2 whyunempcode_m2, contents(freq);
tab jobloss_u_m2 jobloss_0_m2;

* unemployed, M2 - not employed in M4;
gen jobloss_um204=0;
replace jobloss_um204=1 if empstatcode_m1==1 & empstatcode_m2==2 & whyunempcode_m2>=1 & (empstatcode_m4==2 );
* unemployed, M2 - employed in M4;
gen jobloss_um2E4=0;
replace jobloss_um2E4=1 if empstatcode_m1==1 & empstatcode_m2==2 & whyunempcode_m2>=1 & (empstatcode_m4==1);
table jobloss_u_m2 jobloss_um204, contents(freq);
table jobloss_u_m2 jobloss_um2E4, contents(freq);
table jobloss_um204 jobloss_um2E4, contents(freq);

* unemployed, M2 - not emloyed M5;
gen jobloss_um205=0;
replace jobloss_um205=1 if empstatcode_m1==1 & empstatcode_m2==2 & whyunempcode_m2>=1 & empstatcode_m5==2;
table jobloss_u_m2 jobloss_um205, contents(freq);
tab jobloss_u_m2 jobloss_um205;
* unemployed, M2 - emloyed M5;
gen jobloss_um2E5=0;
replace jobloss_um2E5=1 if empstatcode_m1==1 & empstatcode_m2==2 & whyunempcode_m2>=1 & empstatcode_m5==1;
table jobloss_u_m2 jobloss_um2E5, contents(freq);
tab jobloss_u_m2 jobloss_um2E5;
tab jobloss_um205 jobloss_um2E5;
tab jobloss_um205 jobloss_um2E5 if jobloss_u_m2==1;

* unemployed, M2 M6, stricter unemp status;
gen jobloss_u_m2inv=0;
replace jobloss_u_m2inv=1 if empstatcode_m1==1 & empstatcode_m2==2 & whyunempcode_m2==1;
gen jobloss_u_m6inv=0;
replace jobloss_u_m6inv=1 if empstatcode_m5==1 & empstatcode_m6==2 & whyunempcode_m6==1;
table jobloss_u_m2inv empstatcode_m2 whyunempcode_m2, contents(freq);
tab jobloss_u_m2 jobloss_u_m2inv, missing; 
tab jobloss_u_m2inv jobloss_u_m6inv, missing;

* employment, M5;
gen labforce_m5=0;
replace labforce_m5=1 if empstatcode_m5==1 | empstatcode_m5==2 & whyunempcode_m5>=1;
tab employed_m5 whyunempcode_m5;
tab labforce_m5 whyunempcode_m5;
tab labforce_m5 employed_m5;

* job loss, M6;
gen jobloss_0_m6=0;
replace jobloss_0_m6=1 if empstatcode_m5==1 & empstatcode_m6==2;
tab jobloss_0_m2 jobloss_0_m6;

* unemployed, M6;
gen jobloss_u_m6=0;
replace jobloss_u_m6=1 if empstatcode_m5==1 & empstatcode_m6==2 & whyunempcode_m6>=1;
tab jobloss_u_m2 jobloss_u_m6;

* persistent non-employment;
gen jobloss_0_m5=0;
replace jobloss_0_m5=1 if empstatcode_m1==1 & employed_m5==0;

******** Control Variables ********;

* indicators for year and start sequence of first rotation group relative to FDIC survey;
tabulate start_seq, generate(start_seq_);
gen start_seq_123=0;
replace start_seq_123=1 if start_seq==1 | start_seq==2 | start_seq==3;
tabulate yfdic, generate(yfdic_);
rename yfdic_1 yfdic_2011;
rename yfdic_2 yfdic_2013;
rename yfdic_3 yfdic_2015;
rename yfdic_4 yfdic_2017;
rename yfdic_5 yfdic_2019;

* recode categorical controls;
* Age;
gen agecat=0;
replace agecat=1 if age>=17 & age<35;
replace agecat=2 if age>=35 & age<55;
replace agecat=3 if age>=55 & age<99;
* convert to categorical;
forvalues val=1/3 {;
	gen agecat_`val'=0;
	replace agecat_`val'=1 if agecat==`val';
	};
* Female;
gen female=0;
replace female=1 if sex==2;
tab female sex;
* White non-Hispanic;
gen racewht=0;
replace racewht=1 if race==100 & hispan==0;
* Hispanic;
gen racehsp=0;
replace racehsp=1 if hispan>0;
* Black, non-Hispanic;
gen raceblk=0;
replace raceblk=1 if hispan==0 & race==200;
* Asian, AIAN, NPPI, Other, Two or more, non-Hispanic;
gen raceoth=0;
replace raceoth=1 if hispan==0 & race!=100 & race!=200;
* Check race ethnicity;
tab racewht;
tab racehsp;
tab raceblk;
tab raceoth;
* Married;
gen married=0;
replace married=1 if marst==1;
tab married marst;
* Education, Ass. degree or higher;
gen degree=0;
replace degree=1 if educ>=91;
tab degree educ;
* Full time;
gen fulltime=0;
replace fulltime=1 if wkstat==11;
tab fulltime wkstat;
* Native born;
gen native=0;
replace native=1 if bpl==9900;
* Occupation (https://cps.ipums.org/cps/codes/occ_2011_codes.shtml);
gen occagg=999;
replace occagg=0 if occ>=10 & occ<=950; * managers and business analysts;
replace occagg=1 if occ>=1000 & occ<=1965; * knowledge workers;
replace occagg=2 if occ>=2000 & occ<=2960; * creative, instructional, and caring;
* Industry;
gen indagg=0;
replace indagg=1 if ind>=170 & ind<=490 | ind==770; * agricutlure and mining or construction;
replace indagg=2 if ind>=1070 & ind<=3990; * manufacturing;
replace indagg=2 if ind>=0570 & ind<=0690; * utilities;
replace indagg=2 if ind>=4070 & ind<=4590; * wholesale;
replace indagg=2 if ind>=6070 & ind<=6390; * transportation and delivery;
replace indagg=3 if ind>=4670 & ind<=5790; * retail;
replace indagg=3 if ind>=6470 & ind<=7070; * information;
replace indagg=3 if ind>=7080 & ind<=7790 | ind>=8560 & ind<=9290; * services, entertainment, repair;
replace indagg=4 if ind>=7860 & ind<=8470 | ind>=9370 & ind<=9890; * education and healthcare or government;
* convert to categorical;
forvalues val=1/4 {;
	gen indagg_`val'=0;
	replace indagg_`val'=1 if indagg==`val';
	};
* Class of worker;
gen selfemp=0;
replace selfemp=1 if classwkr==13 | classwkr==14;
* Multiple jobs;
gen secondjob=0;
replace secondjob=1 if multjob==2;
* Hours at other job (truncate to 40, some are 99 and more than main job);
gen hrsotherjob=0;
replace hrsotherjob=uhrswork2 if uhrswork2<997;
replace hrsotherjob=40 if hrsotherjob>40;
* Same employer;
tab empsame;
* Housing tenure;
gen homeown=0;
replace homeown=1 if hhtenure==1;
* ordered version of faminc (using values imputed to first month, when missing);
gen faminc_ord=0;
replace faminc_ord=1 if faminc_first>=100 & faminc_first<=500; * 0 - 19,999;
replace faminc_ord=2 if faminc_first>=600 & faminc_first<=730; * 20,000 - 39,999;
replace faminc_ord=3 if faminc_first>=740 & faminc_first<=820; * 40,000 - 59,999;
replace faminc_ord=4 if faminc_first>=830 & faminc_first<=841; * 60,000 - 99,999;
replace faminc_ord=5 if faminc_first==842; * 100,000 - 149,999;
replace faminc_ord=6 if faminc_first==843; * 150,000 and over;
tab faminc_first faminc_ord;
tab faminc_ord;
* convert to categorical;
forvalues val=1/6 {;
	gen faminc_ord_`val'=0;
	replace faminc_ord_`val'=1 if faminc_ord==`val';
	};
gen faminc_ord_456=0;
replace faminc_ord_456=1 if faminc_ord==4 | faminc_ord==5 | faminc_ord==6;
* coded version of faminc;
sum i.faminc_ord;
* lower income renter (for use in broader sample);
gen lowincrent=0;
replace lowincrent=1 if homeown==0 & inlist(faminc_ord,1,2);
* CBA size (non-metro, under a million, over a million);
gen cbsasz_nonmet=0;
replace cbsasz_nonmet=1 if cbsasz==0;
gen cbsasz_undmil=0;
replace cbsasz_undmil=1 if inlist(cbsasz,1,2,3);
gen cbsasz_ovrmil=0;
replace cbsasz_ovrmil=1 if inlist(cbsasz,4,5,6);
* Region (northeast, midwest, south, west);
gen region_ne=0;
replace region_ne=1 if inlist(region,11,12);
gen region_mw=0;
replace region_mw=1 if inlist(region,21,22);
gen region_so=0;
replace region_so=1 if inlist(region,31,32,33);
gen region_we=0;
replace region_we=1 if inlist(region,41,42);

* household number of employed persons, exactly 1 (all should have at least one) or more than 1;
gen hhnumemp1=0;
replace hhnumemp1=1 if hhnumemp==1;
tab hhnumemp hhnumemp1;

* save;
save unbanked${vnum}_${vers}_personlevelprejob, replace;

******** Collapse by first employed person down to household level *******;

* first, keep only those who are employed in first month MIS=1;
keep if empstatcode_m1==1;

* now collapse employment variables by hh, retaining information for the first person;
collapse (first) cpsidp classwkr selfemp wkstat fulltime multjob secondjob indagg ind indagg_1 indagg_2 indagg_3 indagg_4, by(hh2unum);
rename cpsidp cpsidpfirst;

* save;
keep hh2unum cpsidpfirst classwkr selfemp wkstat fulltime multjob secondjob indagg ind indagg_1 indagg_2 indagg_3 indagg_4;
save unbanked${vnum}_${vers}_jobvars, replace;

******** Define household variables ********;
use unbanked${vnum}_${vers}_personlevelprejob, clear;

* household definition (yfdic hrhhid hrhhid2);
* persons before restrictions (could also use cpsidp);
by hh2unum pernum, sort: gen nvals = _n == 1;
count if nvals;
drop nvals;
* households before restrictions;
by hh2unum, sort: gen nvals = _n == 1;
count if nvals;
drop nvals;
* sort for consistency;
sort hh2unum pernum;

* response pattern;
egen hhpattern_basic=max(pattern_basic), by(hh2unum);
egen hhpattern_basic_emp=max(pattern_basic) if empstatcode_m1==1, by(hh2unum);
egen hhpattern_basic_emp15=max(pattern_basic) if empstatcode_m1==1 | empstatcode_m5==1, by(hh2unum);

* summarize longitudinal treatment measures for all persons in household;
egen hhjobloss_0_mm=max(jobloss_0_mm), by(hh2unum);
egen hhjobloss_0_m2=max(jobloss_0_m2), by(hh2unum);
egen hhjobloss_0_m6=max(jobloss_0_m6), by(hh2unum);
egen hhjobloss_u_mm=max(jobloss_u_mm), by(hh2unum);
egen hhjobloss_u_m2=max(jobloss_u_m2), by(hh2unum);
egen hhjobloss_u_m2inv=max(jobloss_u_m2inv), by(hh2unum);
egen hhjobloss_u_m6=max(jobloss_u_m6), by(hh2unum);
egen hhjobloss_u_m6inv=max(jobloss_u_m6inv), by(hh2unum);
* year later outcomes;
egen hhemployed_m5=max(employed_m5), by(hh2unum);
egen hhlabforce_m5=max(labforce_m5), by(hh2unum);
* m2 plus m5 nonemployment;
egen hhjobloss_um205=max(jobloss_um205), by(hh2unum);
egen hhjobloss_um2E5=max(jobloss_um2E5), by(hh2unum);
* for case of more than one person having job loss, designate as re-employed if one in HH has found job - there has been some recovery;
replace hhjobloss_um205=0 if hhjobloss_um205==1 & hhjobloss_um2E5==1;
* m2 plus m4 nonemployment;
egen hhjobloss_um204=max(jobloss_um204), by(hh2unum);
egen hhjobloss_um2E4=max(jobloss_um2E4), by(hh2unum);
* for case of more than one person having job loss, designate as re-employed if one in HH has found job - there has been some recovery;
replace hhjobloss_um204=0 if hhjobloss_um204==1 & hhjobloss_um2E4==1;

* for person level analysis with pes2a, generate variable for other job loss;
gen othjobloss_0_m2=0;
replace othjobloss_0_m2=1 if hhjobloss_0_m2==1 & jobloss_0_m2==0;
gen othjobloss_u_m2=0;
replace othjobloss_u_m2=1 if hhjobloss_u_m2==1 & jobloss_u_m2==0;

* file before collapsing to household (or limiting to one record per household);
save unbanked${vnum}_${vers}_personlevel, replace;

* review restrictions for householder;
sum hhnumemp hhjobloss_0_mm hhjobloss_u_mm hhjobloss_0_m2 hhjobloss_u_m2;
tab pernum relate;
tab perrp;
* limit to person 1;
keep if pernum==1;
* relation to householder is 101 (Head/householder);
keep if relate==101;
* households types: 1 (Reference person living with relatives) or 2 (Reference person living without relatives);
keep if perrp==1 | perrp==2;
* review after restrictions
sum hhnumemp hhjobloss_0_mm hhjobloss_u_mm hhjobloss_0_m2 hhjobloss_u_m2;

* persons after restrictions;
by hh2unum pernum, sort: gen nvals = _n == 1;
count if nvals;
drop nvals;
* households after restrictions;
by hh2unum, sort: gen nvals = _n == 1;
count if nvals;
drop nvals;

******** Merge on HH level variables;

* records to keep at HH level;
gen hhuse=1;

* merge in hh vars;
drop classwkr selfemp wkstat fulltime multjob secondjob indagg ind indagg_1 indagg_2 indagg_3 indagg_4;
merge 1:1 hh2unum using unbanked${vnum}_${vers}_jobvars;
tab _merge hhuse;
tab indagg hhuse;
keep if _merge==3;
drop _merge;

********* Merge on State level variables from auxiliary data;

* from FINRA;
sort statefip yfdic;
merge m:1 statefip yfdic using finra_finlit_stateyr;
egen nmis=rmiss(hh2unum);
tab nmis;
drop nmis;
drop if _merge==2;
drop _merge;

* from BankOn (bankonshare bankonpercap);
sort statefip yfdic;
merge m:1 statefip yfdic using BankOn;
egen nmis=rmiss(hh2unum);
tab nmis;
drop nmis;
drop if _merge==2;
drop _merge;

* sort for consistency;
sort hh2unum;

******** Sample Restrictions, household level ********;

** jobloss month 2 vs. employed - allow attrition;
gen hhjobloss_0_m2_vs_emp=0;
replace hhjobloss_0_m2_vs_emp=1 if hhjobloss_0_m2==1 | hhjobloss_0_mm==0;
** unemployed month 2 vs. employed - allow attrition;
gen hhjobloss_u_m2_vs_emp=0;
replace hhjobloss_u_m2_vs_emp=1 if hhjobloss_u_m2==1 | hhjobloss_0_mm==0;
** jobloss month 2 involuntary vs. employed - allow attrition;
gen hhjobloss_u_m2_vs_emp_inv=0;
replace hhjobloss_u_m2_vs_emp_inv=1 if hhjobloss_u_m2inv==1 | hhjobloss_0_mm==0;

** jobloss month 2 vs. employed - allow attrition - no double job loss;
gen hhjobloss_0_m2_vs_emp_ndjl=0;
replace hhjobloss_0_m2_vs_emp_ndjl=1 if hhjobloss_0_m2==1 & hhjobloss_0_m6==0 | hhjobloss_0_mm==0;
** unemployed month 2 vs. employed - allow attrition;
gen hhjobloss_u_m2_vs_emp_ndjl=0;
replace hhjobloss_u_m2_vs_emp_ndjl=1 if hhjobloss_u_m2==1 & hhjobloss_u_m6==0 | hhjobloss_0_mm==0;
** jobloss month 2 involuntary vs. employed - allow attrition;
gen hhjobloss_u_m2_vs_emp_inv_ndjl=0;
replace hhjobloss_u_m2_vs_emp_inv_ndjl=1 if hhjobloss_u_m2inv==1 & hhjobloss_u_m6inv==0 | hhjobloss_0_mm==0;

** jobloss month 2 vs. employed - no attrition;
gen hhjobloss_0_m2_vs_emp_noatt=0;
replace hhjobloss_0_m2_vs_emp_noatt=1 if hhjobloss_0_m2==1 & hhpattern_basic==1 | hhjobloss_0_mm==0 & hhpattern_basic==1;
** unemployed month 2 vs. employed - no attrition;
gen hhjobloss_u_m2_vs_emp_noatt=0;
replace hhjobloss_u_m2_vs_emp_noatt=1 if hhjobloss_u_m2==1 & hhpattern_basic==1 | hhjobloss_0_mm==0 & hhpattern_basic==1;
** jobloss month 2 involuntary vs. employed - no attrition;
gen hhjobloss_u_m2_vs_emp_inv_noatt=0;
replace hhjobloss_u_m2_vs_emp_inv_noatt=1 if hhjobloss_u_m2inv==1 & hhpattern_basic==1 | hhjobloss_0_mm==0 & hhpattern_basic==1;

** jobloss month 2 vs. employed - some attrition - responds up to month 5;
gen hhjobloss_0_m2_vs_emp_patt5=0;
replace hhjobloss_0_m2_vs_emp_patt5=1 if hhjobloss_0_m2==1 & inlist(hhpattern_basic,1,2) | hhjobloss_0_mm==0 & inlist(hhpattern_basic,1,2);
** unemployed month 2 vs. employed - some attrition - responds up to month 5;
gen hhjobloss_u_m2_vs_emp_patt5=0;
replace hhjobloss_u_m2_vs_emp_patt5=1 if hhjobloss_u_m2==1 & inlist(hhpattern_basic,1,2) | hhjobloss_0_mm==0 & inlist(hhpattern_basic,1,2);
** jobloss month 2 involuntary vs. employed - some attrition - responds up to month 5;
gen hhjobloss_u_m2_vs_emp_inv_patt5=0;
replace hhjobloss_u_m2_vs_emp_inv_patt5=1 if hhjobloss_u_m2inv==1 & inlist(hhpattern_basic,1,2) | hhjobloss_0_mm==0 & inlist(hhpattern_basic,1,2);

** unemployed month 2 vs. employed - no attrition, job losers all not re-employed in m5;
gen hhjobloss_um205_vs_emp_noatt=0;
replace hhjobloss_um205_vs_emp_noatt=1 if hhjobloss_um205==1 & hhpattern_basic==1 | hhjobloss_0_mm==0 & hhpattern_basic==1;
gen hhjobloss_um205_vs_m6_noatt=0;
replace hhjobloss_um205_vs_m6_noatt=1 if hhjobloss_um205==1 & hhpattern_basic==1 | hhjobloss_u_m2==0 & hhjobloss_u_m6==1 & hhpattern_basic==1;
** unemployed month 2 vs. employed - no attrition, job losers some (or all) are re-employed in m5;
gen hhjobloss_um2E5_vs_emp_noatt=0;
replace hhjobloss_um2E5_vs_emp_noatt=1 if hhjobloss_um2E5==1 & hhpattern_basic==1 | hhjobloss_0_mm==0 & hhpattern_basic==1;
gen hhjobloss_um2E5_vs_m6_noatt=0;
replace hhjobloss_um2E5_vs_m6_noatt=1 if hhjobloss_um2E5==1 & hhpattern_basic==1 | hhjobloss_u_m2==0 & hhjobloss_u_m6==1 & hhpattern_basic==1;

** unemployed month 2 vs. employed - some attrition, job losers all not re-employed in m5;
gen hhjobloss_um205_vs_emp_patt5=0;
replace hhjobloss_um205_vs_emp_patt5=1 if hhjobloss_um205==1 & inlist(hhpattern_basic,1,2) | hhjobloss_0_mm==0 & inlist(hhpattern_basic,1,2);
gen hhjobloss_um205_vs_m6_patt5=0;
replace hhjobloss_um205_vs_m6_patt5=1 if hhjobloss_um205==1 & inlist(hhpattern_basic,1,2) | hhjobloss_u_m2==0 & hhjobloss_u_m6==1 & inlist(hhpattern_basic,1,2);
** unemployed month 2 vs. employed - some attrition, job losers some (or all) are re-employed in m5;
gen hhjobloss_um2E5_vs_emp_patt5=0;
replace hhjobloss_um2E5_vs_emp_patt5=1 if hhjobloss_um2E5==1 & inlist(hhpattern_basic,1,2) | hhjobloss_0_mm==0 & inlist(hhpattern_basic,1,2);
gen hhjobloss_um2E5_vs_m6_patt5=0;
replace hhjobloss_um2E5_vs_m6_patt5=1 if hhjobloss_um2E5==1 & inlist(hhpattern_basic,1,2) | hhjobloss_u_m2==0 & hhjobloss_u_m6==1 & inlist(hhpattern_basic,1,2);

** jobloss month 2 vs. month 6 - allow attrition;
gen hhjobloss_0_m2_vs_m6=0;
replace hhjobloss_0_m2_vs_m6=1 if hhjobloss_0_m2==1 | hhjobloss_0_m6==1;
** unemployed month 2 vs. month 6 - allow attrition;
gen hhjobloss_u_m2_vs_m6=0;
replace hhjobloss_u_m2_vs_m6=1 if hhjobloss_u_m2==1 | hhjobloss_u_m6==1;
** jobloss month 2 involuntary vs. month 6 involuntary - allow attrition;
gen hhjobloss_u_m2_vs_m6_inv=0;
replace hhjobloss_u_m2_vs_m6_inv=1 if hhjobloss_u_m2inv==1 | hhjobloss_u_m6inv==1;

** jobloss month 2 vs. month 6 - allow attrition - no double job loss;
gen hhjobloss_0_m2_vs_m6_ndjl=0;
replace hhjobloss_0_m2_vs_m6_ndjl=1 if hhjobloss_0_m2==1 & hhjobloss_0_m6==0 | hhjobloss_0_m2==0 & hhjobloss_0_m6==1;
** unemployed month 2 vs. month 6 - allow attrition;
gen hhjobloss_u_m2_vs_m6_ndjl=0;
replace hhjobloss_u_m2_vs_m6_ndjl=1 if hhjobloss_u_m2==1 & hhjobloss_u_m6==0 | hhjobloss_u_m2==0 & hhjobloss_u_m6==1;
** jobloss month 2 involuntary vs. month 6 involuntary - allow attrition;
gen hhjobloss_u_m2_vs_m6_inv_ndjl=0;
replace hhjobloss_u_m2_vs_m6_inv_ndjl=1 if hhjobloss_u_m2inv==1 & hhjobloss_u_m6inv==0 | hhjobloss_u_m2inv==0 & hhjobloss_u_m6inv==1;

** jobloss month 2 vs. month 6 - no attrition;
gen hhjobloss_0_m2_vs_m6_noatt=0;
replace hhjobloss_0_m2_vs_m6_noatt=1 if hhjobloss_0_m2==1 & hhpattern_basic==1 | hhjobloss_0_m6==1 & hhpattern_basic==1;
** unemployed month 2 vs. month 6 - no attrition;
gen hhjobloss_u_m2_vs_m6_noatt=0;
replace hhjobloss_u_m2_vs_m6_noatt=1 if hhjobloss_u_m2==1 & hhpattern_basic==1 | hhjobloss_u_m6==1 & hhpattern_basic==1;
** jobloss month 2 involuntary vs. month 6 involuntary - no attrition;
gen hhjobloss_u_m2_vs_m6_inv_noatt=0;
replace hhjobloss_u_m2_vs_m6_inv_noatt=1 if hhjobloss_u_m2inv==1 & hhpattern_basic==1 | hhjobloss_u_m6inv==1 & hhpattern_basic==1;

** jobloss month 2 vs. month 6 - some attrition - responds up to month 5;
gen hhjobloss_0_m2_vs_m6_patt5=0;
replace hhjobloss_0_m2_vs_m6_patt5=1 if hhjobloss_0_m2==1 & inlist(hhpattern_basic,1,2) | hhjobloss_0_m6==1 & inlist(hhpattern_basic,1,2);
** unemployed month 2 vs. month 6 - some attrition - responds up to month 5;
gen hhjobloss_u_m2_vs_m6_patt5=0;
replace hhjobloss_u_m2_vs_m6_patt5=1 if hhjobloss_u_m2==1 & inlist(hhpattern_basic,1,2) | hhjobloss_u_m6==1 & inlist(hhpattern_basic,1,2);
** jobloss month 2 involuntary vs. month 6 involuntary - some attrition - responds up to month 5;
gen hhjobloss_u_m2_vs_m6_inv_patt5=0;
replace hhjobloss_u_m2_vs_m6_inv_patt5=1 if hhjobloss_u_m2inv==1 & inlist(hhpattern_basic,1,2) | hhjobloss_u_m6inv==1 & inlist(hhpattern_basic,1,2);

* sample restriction based on variables;
** restrict level 2 [including 0,1,2] includes the full sample;
gen restrictlev=2;
** restrict level 1 [including 0,1] requires a further set of restrictions;
replace restrictlev=1 if faminc_ord<=2 & homeown==0;
** restrict level 0 [including 0] is only those satisfying all restrictions;
replace restrictlev=0 if restrictlev==1 & fulltime==0 & secondjob==0;
tab restrictlev, missing;
tab yfdic restrictlev, missing;

******** Save as Stata File ********;

save unbanked${vnum}_${vers}, replace;
save unbanked${vnum}_${vers}_temp, replace;

******** Analysis ********;

* for ju11 only: pre-treatment; 
use unbanked${vnum}_${vers}_temp, clear;
keep if start_seq==4 & restrictlev<2;
tab hhnumemp;
tab hhjobloss_0_m2;
tab hhjobloss_u_m2;

* for ju11 only: immediate; 
use unbanked${vnum}_${vers}_temp, clear;
keep if start_seq==1 & restrictlev<2 | start_seq==2 & restrictlev<2 | start_seq==3 & restrictlev<2;
tab hhnumemp;
tab hhjobloss_0_m2;
tab hhjobloss_u_m2;

erase unbanked${vnum}_${vers}_temp.dta;

***** Load full for anything else *****;
use unbanked${vnum}_${vers}, clear;


***** Now work with person level file again *****;

* identify reference person from hh file;
keep hh2unum cpsidp;
sort hh2unum cpsidp;
save unbanked${vnum}_${vers}_hhref, replace;
use unbanked${vnum}_${vers}_personlevel, clear;
sort hh2unum cpsidp;
merge m:1 hh2unum cpsidp using unbanked${vnum}_${vers}_hhref;
gen hhref=0;
replace hhref=1 if _merge==3;
drop _merge;
tab hhref, missing;

******** Sample Restrictions, person level ********;

*** hh level (for checking parallel construction);

** jobloss month 2 vs. employed - allow attrition;
gen hhjobloss_0_m2_vs_emp=0;
replace hhjobloss_0_m2_vs_emp=1 if hhjobloss_0_m2==1 | hhjobloss_0_mm==0;
** unemployed month 2 vs. employed - allow attrition;
gen hhjobloss_u_m2_vs_emp=0;
replace hhjobloss_u_m2_vs_emp=1 if hhjobloss_u_m2==1 | hhjobloss_0_mm==0;
** jobloss month 2 involuntary vs. employed - allow attrition;
gen hhjobloss_u_m2_vs_emp_inv=0;
replace hhjobloss_u_m2_vs_emp_inv=1 if hhjobloss_u_m2inv==1 | hhjobloss_0_mm==0;

** jobloss month 2 vs. month 6 - allow attrition;
gen hhjobloss_0_m2_vs_m6=0;
replace hhjobloss_0_m2_vs_m6=1 if hhjobloss_0_m2==1 | hhjobloss_0_m6==1;
** unemployed month 2 vs. month 6 - allow attrition;
gen hhjobloss_u_m2_vs_m6=0;
replace hhjobloss_u_m2_vs_m6=1 if hhjobloss_u_m2==1 | hhjobloss_u_m6==1;
** jobloss month 2 involuntary vs. month 6 involuntary - allow attrition;
gen hhjobloss_u_m2_vs_m6_inv=0;
replace hhjobloss_u_m2_vs_m6_inv=1 if hhjobloss_u_m2inv==1 | hhjobloss_u_m6inv==1;

*** person level;

** jobloss month 2 vs. employed - allow attrition;
gen jobloss_0_m2_vs_emp=0;
replace jobloss_0_m2_vs_emp=1 if jobloss_0_m2==1 | jobloss_0_mm==0;
** unemployed month 2 vs. employed - allow attrition;
gen jobloss_u_m2_vs_emp=0;
replace jobloss_u_m2_vs_emp=1 if jobloss_u_m2==1 | jobloss_0_mm==0;
** jobloss month 2 involuntary vs. employed - allow attrition;
gen jobloss_u_m2_vs_emp_inv=0;
replace jobloss_u_m2_vs_emp_inv=1 if jobloss_u_m2inv==1 | jobloss_0_mm==0;

** jobloss month 2 vs. month 6 - allow attrition;
gen jobloss_0_m2_vs_m6=0;
replace jobloss_0_m2_vs_m6=1 if jobloss_0_m2==1 | jobloss_0_m6==1;
** unemployed month 2 vs. month 6 - allow attrition;
gen jobloss_u_m2_vs_m6=0;
replace jobloss_u_m2_vs_m6=1 if jobloss_u_m2==1 | jobloss_u_m6==1;
** jobloss month 2 involuntary vs. month 6 involuntary - allow attrition;
gen jobloss_u_m2_vs_m6_inv=0;
replace jobloss_u_m2_vs_m6_inv=1 if jobloss_u_m2inv==1 | jobloss_u_m6inv==1;

* sample restriction based on variables;
** restrict level 2 [including 0,1,2] includes the full sample;
gen restrictlev=2;
** restrict level 1 [including 0,1] requires a further set of restrictions;
replace restrictlev=1 if faminc_ord<=2 & homeown==0;
** restrict level 0 [including 0] is only those satisfying all restrictions;
replace restrictlev=0 if restrictlev==1 & fulltime==0 & secondjob==0;
tab restrictlev, missing;
tab yfdic restrictlev, missing;

** restrict level 2 [including 0,1,2] includes the full sample;
gen restrictlevallinc=2;
** restrict level 1 [including 0,1] requires a further set of restrictions;
replace restrictlevallinc=1 if faminc_ord<=4 & homeown==0;
** restrict level 0 [including 0] is only those satisfying all restrictions;
replace restrictlevallinc=0 if restrictlevallinc==1 & fulltime==0 & secondjob==0;
tab restrictlevallinc, missing;
tab yfdic restrictlevallinc, missing;

******** Save as Stata File ********;

save unbanked${vnum}_${vers}_personest, replace;
save unbanked${vnum}_${vers}_personest_temp, replace;

******** Analysis ********;

* for ju11 only: pre-treatment; 
use unbanked${vnum}_${vers}_personest_temp, clear;
keep if start_seq==4 & restrictlev<2;
tab hhnumemp, missing;
tab hhjobloss_0_m2 jobloss_0_m2, missing;
tab hhjobloss_u_m2 jobloss_u_m2, missing;

* for ju11 only: immediate; 
use unbanked${vnum}_${vers}_personest_temp, clear;
keep if start_seq==1 & restrictlev<2 | start_seq==2 & restrictlev<2 | start_seq==3 & restrictlev<2;
tab hhnumemp, missing;
tab hhjobloss_0_m2 jobloss_0_m2, missing;
tab hhjobloss_u_m2 jobloss_u_m2, missing;

* review restrictions for householder;
tab pernum hhref, missing;
tab relate hhref, missing;
tab perrp hhref, missing;

erase unbanked${vnum}_${vers}_personest_temp.dta;

***** Load full for anything else *****;
use unbanked${vnum}_${vers}_personest, clear;
