* Unbanked results;
* By Mark Kutzbach;
#delimit;

* Use corresponding file created in sumstats;
display "unbanked${vnum}_${vers}${datasuf}";
use unbanked${vnum}_${vers}${datasuf}, clear;

******** Global Lists ********;

* list of outcomes under consideration;
global outcomevarsall="hunbank hunbanklong hunbankshtr use12pp use12mo use12cc use12pw use12pd";

* list of treatments under consideration;
global treatvarsall="hhjobloss_0_m2 hhjobloss_u_m2 hhjobloss_u_m2inv";

* list of controls under consideration;
global controlvarsall="age agecat_1 agecat_2 agecat_3 female racewht racehsp raceblk raceoth native married degree";
global controlvarsall="${controlvarsall} selfemp fulltime";
global controlvarsall="${controlvarsall} indagg_1 indagg_2 indagg_3 indagg_4";
global controlvarsall="${controlvarsall} faminc_ord_1 faminc_ord_2 faminc_ord_3 faminc_ord_4 faminc_ord_5 faminc_ord_6";
global controlvarsall="${controlvarsall} homeown hhnum hhnumemp";
global controlvarsall="${controlvarsall} yfdic_2011 yfdic_2013 yfdic_2015 yfdic_2017 yfdic_2019";
global controlvarsall="${controlvarsall} start_seq_1 start_seq_2 start_seq_3 start_seq_4";

* list of controls used for estimation;
global controlvars="agecat_1 agecat_3 female racehsp raceblk raceoth native married degree";
global controlvars="${controlvars} selfemp fulltime";
global controlvars="${controlvars} indagg_1 indagg_2 indagg_3";
global controlvars="${controlvars} faminc_ord_2 faminc_ord_3 faminc_ord_4 faminc_ord_5 faminc_ord_6";
global controlvars="${controlvars} hhnum hhnumemp";

* time controls used in some non-factor variable specifications; 
global controlvarstime="i.yfdic";
global controlvarstime="${controlvarstime} i.start_seq";
global controlvarstimeinds="yfdic_2013 yfdic_2015 yfdic_2017 yfdic_2019";
global controlvarstimeinds="${controlvarstimeinds} start_seq_1 start_seq_2 start_seq_3";
global controlvarstimeindsalt="yfdic_2013 yfdic_2015 yfdic_2017 yfdic_2019";
global controlvarstimeindsalt="${controlvarstimeindsalt} start_seq_1 start_seq_2";

* sample restriction based on years, for use with yfdic;
** all years;
global yearsall="2011, 2013, 2015, 2017, 2019";
** years with questions about last 30 days;
global years30d="2011, 2013";

* sample restriction based on start sequence, for use with start_seq;
** all sequences, for use with long run;
global seqall="1, 2, 3, 4";
** sequence start, for use with short run;
global seqbeg="1, 2, 3";
** sequence start, for use with short run;
global seqalt="1, 2";
** sequence end, for use with short run placebo (job loss after FDIC response);
global seqend="4";

******** Programs ********;
* return list gives stored results;

* Select a subset of input sample (not reversible);
capture program drop sampleselect;
program define sampleselect;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	display "Results for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	tab temprestrict;
	keep if temprestrict==1;
end;

* Check covariate thickness (observation of treatment by outcome);
capture program drop covarthick;
program define covarthick;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	* 11: Outcome variable;
	display "Covariate thickness for `1' `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* Check thickness;
	table `10' `11' if temprestrict==1, contents(freq);
	* drop restriction;
	drop temprestrict;
end;

* Summary Statistics;
capture program drop sumstat;
program define sumstat;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	display "Summary statistics for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	tab temprestrict;
	* summary stats, overall;
	tabstat ${outcomevarsall} ${treatvarsall} ${robustvarsall} ${controlvarsall} ///
	    if temprestrict==1, stat(n sum min max mean) col(statistics) save;
	ret li;
	matrix statsrow=r(StatTotal);
	matrix statscol=statsrow';
	* summary stats by - treated;
	tabstat ${outcomevarsall} ${treatvarsall} ${robustvarsall} ${controlvarsall} ///
	    if temprestrict==1 & `10'==1, stat(n sum min max mean) col(statistics) save;
	ret li;
	matrix statsrow=r(StatTotal);
	matrix statscol_treated=statsrow';
	* summary stats by - control;
	tabstat ${outcomevarsall} ${treatvarsall} ${robustvarsall} ${controlvarsall} ///
	    if temprestrict==1 & `10'==0, stat(n sum min max mean) col(statistics) save;
	ret li;
	matrix statsrow=r(StatTotal);
	matrix statscol_control=statsrow';
	* difference in means of variable across two groups (ttest is same statistic as regression of one on the other);
	* differences, must initiate with first row;
	matrix ttests=[1,1,1,1];
	foreach var in ${outcomevarsall} ${treatvarsall} ${robustvarsall} ${controlvarsall} {;
		ttest `var' if temprestrict==1, by(`10');
		matrix diff=r(mu_2)-r(mu_1);
		matrix se=r(se);
		matrix t=r(t);
		matrix p=r(p);
		matrix ttests=(ttests\diff,se,t,p);
		};
		* remove first row;
		matrix ttests=ttests[2...,1..4];
	* output results;
	matrix statscol=statscol,statscol_treated[1...,1],statscol_control[1...,1],statscol_treated[1...,5],statscol_control[1...,5],ttests[1...,1..4];
	matrix colnames statscol = "n" "sum" "min" "max" "mean" "n_trtd" "n_ctrl" "mean_trtd" "mean_ctrl" "diff" "se" "t" "p";
	estout matrix(statscol) using sumstats${vnum}_${vers}${verspost}_`1'_`9'.txt, replace noabbrev varwidth(30) style(fixed) ///
	prehead(Summary Statistics for version ${vnum} and sample ${vers}${verspost}, sample is `1' `9', treatment is `10') ///
	postfoot("Sample restricted to `1' in `2', `3' in `4', `5' in `6', `7' in `8'");
	* explain treatment;
	reg `10' ${controlvars} ${controlvarstimeinds} if temprestrict==1, robust;
	estimates store est_`10';
	* drop restriction;
	drop temprestrict;
end;

* Collect results of explaining treatment (must come after sumstat, uses stored est_, see above);
capture program drop treatexplain;
program define treatexplain;
	* 1: stored estimates;
	* 2: name of ouptut file;
	* 3: names of models;
	* 4: table title;
	* 5: table note;
	* 6: variable order;
	* round to three decimals;
	estout `1' using treatexplain${vnum}_${vers}${verspost}_`2'.txt, c(b(star fmt(%9.3f)) se(par(`"("'`")"') fmt(%9.3f))) ///
	stats(r2 r2_a F N N_clust, fmt(%12.3f %12.3f %12.1f %12.0f %12.0f)) ///
	starlevels(* 0.10 ** 0.05 *** 0.01) noabbrev varwidth(30) varlabels(_cons Constant) ///
	mlabel(`3') title(`4') note(`5') order(`6') keep(`6') style(fixed) replace;
end;

* Full model estimates;
capture program drop estmodcpsfull;
program define estmodcpsfull;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	* 11: Outcome variable;
	* 12: Order: replace or append;
	* 13: Filename;
	* 14: Controls vars: controlvars;
	* 15: Controls time: controlvarstimeinds;
	display "Estimation results for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* estimation;
	reg `11' `10' `14' `15' ///
	    if temprestrict==1 ///
		, robust;
	* output;
	outreg2 using fullestimates${vnum}_${vers}${verspost}_`1'_`13'.xls, `12' ctitle(`11') label;
	* drop restriction;
	drop temprestrict;
end;

* Estimation program;
capture program drop estmodcps;
program define estmodcps;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable (binary);
	* 11: Outcome variable;
	display "Estimation results for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* Summary stats (needs binary treatment);
	* tab hhjobloss_u_m234 if hhjobloss_u_m2_vs_emp==1 & inlist(restrictlev,0,1) & inlist(yfdic,${yearsall}) & inlist(start_seq,${seqbeg}) & hunbankshtr!=.;
	tabstat `11' ///
	    if temprestrict==1 ///
		, by(`10') stat(n mean) col(statistics) save;
	ret li;
	matrix stat0=r(Stat1);
	matrix stat1=r(Stat2);
	matrix totals=r(StatTotal);
	matrix stats=(totals,stat1,stat0)';
	matrix results=(stats[.,1..1]\stats[.,2..2]);
	matrix rownames results = "Sample N" "Treat N" "Control N" "Sample mean" "Treat mean" "Control mean";
	matrix colnames results = "`9'";
	matrix list results;
	* No controls regression;
	reg `11' `10' ${controlvarstime} ///
	    if temprestrict==1 ///
		, robust;
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "OLS noctrl beta pt" "OLS noctrl beta se" "OLS noctrl beta pv";
	matrix results=(results\resultsadd);
	* With controls OLS;
	reg `11' `10' ${controlvars} ${controlvarstime} ///
	    if temprestrict==1 ///
		, robust;
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "OLS wictrl beta pt" "OLS wictrl beta se" "OLS wictrl beta pv";
	matrix results=(results\resultsadd);
	* Output results;
	matrix list results;
	capture confirm matrix resultsall;
	display _rc;
	if _rc>0 {; matrix resultsall=results;};
	if _rc==0 {; matrix resultsall=(resultsall,results);};
	matrix list resultsall;
	* drop restriction;
	drop temprestrict;
end;

* Output estimation results program;
capture program drop outputresults;
program define outputresults;
	* 1: Title
	* 2: Filename;
	estout matrix(resultsall) using estimates${vnum}_${vers}${verspost}_`2'.txt, replace noabbrev varwidth(30) style(fixed) ///
	prehead(Estimation Results for version ${vnum} and sample ${vers}${verspost} with treatment `1',) ///
	postfoot("No controls: ${controlvarstime} and constant; " "With controls: ${controlvars} ${controlvarstime} and constant");
	matrix drop resultsall;
end;

* Estimation program, with interaction;
capture program drop estmodcpsintr;
program define estmodcpsintr;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	* 11: Outcome variable;
	* 12: Interactions;
	* 13: Controls to drop;
	display "Estimation results for `9'";
	* Summary of interaction;
	display "interactions `12'";
	local intrs : word count `12';
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* drop some controls (go through control variables and drop as needed);
	global controlvarsintr="$controlvars";
	global controlvarstimeintr="$controlvarstime";
	local dropvarlist "`13' none";
	local dropvarcount : word count `dropvarlist';
		forval v=1/`dropvarcount' {;
		local var `:word `v' of `dropvarlist'';
		global controlvarsintr: subinstr global controlvarsintr "`var'" "", all;
		global controlvarstimeintr: subinstr global controlvarstimeintr "`var'" "", all;
		};
	* Summary stats;
	display "here1";
	tabstat `11' ///
	    if temprestrict==1 ///
		, stat(n mean) col(statistics) save;
	ret li;
	matrix totals=r(StatTotal);
	* Main effect, no interaction;
	display "here2";
	tabstat `11' ///
	    if temprestrict==1 ///
		, by(`10') stat(n mean) col(statistics) save;
	ret li;
	matrix statb1=r(Stat2);
	* create variable for if any of the interaction effects are positive;
	gen intrpos=0;
		forval i=1/`intrs' {;
		local int `:word `i' of `12'';
	replace intrpos=1 if `int'>0;
			};
	* Dummy with positive value, but no main effect;
	display "here3";
	tabstat `11' ///
	    if temprestrict==1 & intrpos>0 ///
		, by(`10') stat(n mean) col(statistics) save;
	ret li;
	matrix statd1=r(Stat1);
	* Interaction (but check if dummy and main effect are mutually exclusive);
	capture confirm matrix r(Stat2);
	display _rc;
	if _rc>0 {; matrix stati1=(0\.);};
	if _rc==0 {; matrix stati1=r(Stat2);};
	* Remaining observations not in treatment, dummy, or interaction;
	display "here4";
	tabstat `11' ///
	    if temprestrict==1 & `10'==0 & intrpos==0 ///
		, stat(n mean) col(statistics) save;
	ret li;
	matrix stat0=r(StatTotal);
	* put them together;
	matrix stats=(totals,stat0,statb1,statd1,stati1)';
	matrix results=(stats[.,1..1]\stats[.,2..2]);
	matrix rownames results = "Sample N" "Control N" "Trt B N" "Trt D N" "Trt I N" "Sample outcome mean" "Control outcome mean" "Trt B outcome mean" "Trt D outcome mean" "Trt I outcome mean";
	matrix colnames results = "`9'";
	matrix list results;
	* Stata has trouble with c. for continuous interaction summary stats here, see parsing https://www.stata.com/manuals/pmacro.pdf;
	local intrsum="`12'";
	local intrpre=substr("`12'",1,2);
	if "`intrpre'"=="c." {;
		display "Has continuous interaction `intrsum'";
		local intrlen: strlen local 12;
		local intrchr=`intrlen'-2;
		local intrsum=substr("`12'",3,`intrchr');
	};
	display "There are `intrs' interaction variables (continuous or binary), summarize `intrsum'";
		forval i=1/`intrs' {;
		local int `:word `i' of `intrsum'';
	tabstat `int' ///
	    if temprestrict==1 ///
		, by(`10') stat(n mean) col(statistics) save;
	ret li;
	matrix stat1=r(Stat2);
	matrix totals=r(StatTotal);
	matrix stats=(totals,stat1)';
	matrix resultsintr=(stats[.,2..2]);
	matrix rownames resultsintr = "Samp i`i' `int' mean" "Treat i`i' `int' mean";
	matrix results=(results\resultsintr);
		};
	* No controls regression;
	reg `11' `10'##(`12') ${controlvarstimeintr} ///
	    if temprestrict==1 ///
		, robust;
	matrix est=r(table);
	matrix resultsaddbeta=(est[1,2..2]\est[2,2..2]\est[4,2..2]);
	matrix rownames resultsaddbeta = "OLS noctrl beta pt" "OLS noctrl beta se" "OLS noctrl beta pv";
	matrix results=(results\resultsaddbeta);
		forval i=1/`intrs' {;
		local int `:word `i' of `12'';
		local ic=2+2*`i';
	matrix resultsadddelt=(est[1,`ic'..`ic']\est[2,`ic'..`ic']\est[4,`ic'..`ic']);
	if "`intrpre'"=="c." {; local int="`intrsum'";};
	matrix rownames resultsadddelt = "OLS noctrl d`i' `int' pt" "OLS noctrl d`i' `int' se" "OLS noctrl d`i' `int' pv";
	matrix results=(results\resultsadddelt);
		};
		forval i=1/`intrs' {;
		local int `:word `i' of `12'';
		local ic=2+2*`intrs'+4*`i';
		di "Using columns `ic'";
	matrix resultsaddintr=(est[1,`ic'..`ic']\est[2,`ic'..`ic']\est[4,`ic'..`ic']);
	if "`intrpre'"=="c." {; local int="`intrsum'";};
	matrix rownames resultsaddintr = "OLS noctrl i`i' `int' pt" "OLS noctrl i`i' `int' se" "OLS noctrl i`i' `int' pv";
	matrix results=(results\resultsaddintr);
		};
	* test significance of beta effect and dummy effect (not interaction);
		forval i=1/`intrs' {;
		local int `:word `i' of `12'';
	test 1.`10'=1.`int';
	matrix intrFstat=r(F);
	matrix intrPstat=r(p);
	matrix resultsaddstat=(intrFstat\intrPstat);
	matrix rownames resultsaddstat = "OLS noctrl bd i`i' F" "OLS noctrl bd i`i' p";
	matrix results=(results\resultsaddstat);
		};
	* With controls OLS;
	reg `11' `10'##(`12') ${controlvarsintr} ${controlvarstimeintr} ///
	    if temprestrict==1 ///
		, robust;
	matrix est=r(table);
	matrix resultsaddbeta=(est[1,2..2]\est[2,2..2]\est[4,2..2]);
	matrix rownames resultsaddbeta = "OLS wictrl beta pt" "OLS wictrl beta se" "OLS wictrl beta pv";
	matrix results=(results\resultsaddbeta);
		forval i=1/`intrs' {;
		local int `:word `i' of `12'';
		local ic=2+2*`i';
	matrix resultsadddelt=(est[1,`ic'..`ic']\est[2,`ic'..`ic']\est[4,`ic'..`ic']);
	if "`intrpre'"=="c." {; local int="`intrsum'";};
	matrix rownames resultsadddelt = "OLS wictrl d`i' `int' pt" "OLS wictrl d`i' `int' se" "OLS wictrl d`i' `int' pv";
	matrix results=(results\resultsadddelt);
		};
		forval i=1/`intrs' {;
		local int `:word `i' of `12'';
		local ic=2+2*`intrs'+4*`i';
	matrix resultsaddintr=(est[1,`ic'..`ic']\est[2,`ic'..`ic']\est[4,`ic'..`ic']);
	if "`intrpre'"=="c." {; local int="`intrsum'";};
	matrix rownames resultsaddintr = "OLS wictrl i`i' `int' pt" "OLS wictrl i`i' `int' se" "OLS wictrl i`i' `int' pv";
	matrix results=(results\resultsaddintr);
		};
	* test significance of beta effect and dummy effect (not interaction);
		forval i=1/`intrs' {;
		local int `:word `i' of `12'';
	test 1.`10'=1.`int';
	matrix intrFstat=r(F);
	matrix intrPstat=r(p);
	matrix resultsaddstat=(intrFstat\intrPstat);
	matrix rownames resultsaddstat = "OLS wictrl bd i`i' F" "OLS wictrl bd i`i' p";
	matrix results=(results\resultsaddstat);
		};
	* Output results;
	matrix list results;
	capture confirm matrix resultsall;
	display _rc;
	if _rc>0 {; matrix resultsall=results;};
	if _rc==0 {; matrix resultsall=(resultsall,results);};
	matrix list resultsall;
	* drop restriction;
	drop temprestrict;
	drop intrpos;
end;

* Output estimation results program - for models with an interaction;
capture program drop outputresultsintr;
program define outputresultsintr;
	* 1: Title
	* 2: Filename;
	* 3: Interaction variable names;
	estout matrix(resultsall) using estimates${vnum}_${vers}${verspost}_`2'.txt, replace noabbrev varwidth(30) style(fixed) ///
	prehead(Estimation Results for version ${vnum} and sample ${vers}${verspost} with treatment `1',) ///
	postfoot("Main effect: see file name, Interaction: `3'; " "No controls: ${controlvarstimeintr} and constant; " "With controls: ${controlvarsintr} ${controlvarstimeintr} and constant");
	matrix drop resultsall;
end;

* Estimation program with option to specify the control variables;
capture program drop estmodcpscont;
program define estmodcpscont;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	* 11: Outcome variable;
	* 12: Controlvars dummy variables for fixed effects ${controlvarstime};
	* 13: Controlvars selected ${controlvars};
	display "Estimation results for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* Summary stats (should make it for positive negative values of treatment variable, problem for intensity);
	* tab hhjobloss_u_m234 if hhjobloss_u_m2_vs_emp==1 & inlist(restrictlev,0,1) & inlist(yfdic,${yearsall}) & inlist(start_seq,${seqbeg}) & hunbankshtr!=.;
	tabstat `11' ///
	    if temprestrict==1 ///
		, by(`10') stat(n mean) col(statistics) save;
	ret li;
	matrix stat0=r(Stat1);
	matrix stat1=r(Stat2);
	matrix totals=r(StatTotal);
	matrix stats=(totals,stat1,stat0)';
	matrix results=(stats[.,1..1]\stats[.,2..2]);
	matrix rownames results = "Sample N" "Treat N" "Control N" "Sample mean" "Treat mean" "Control mean";
	matrix colnames results = "`9'";
	matrix list results;
	* No controls regression;
	reg `11' `10' `12' ///
	    if temprestrict==1 ///
		, robust;
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "OLS noctrl beta pt" "OLS noctrl beta se" "OLS noctrl beta pv";
	matrix results=(results\resultsadd);
	* With controls OLS;
	reg `11' `10' `12' `13' ///
	    if temprestrict==1 ///
		, robust;
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "OLS wictrl beta pt" "OLS wictrl beta se" "OLS wictrl beta pv";
	matrix results=(results\resultsadd);
	* Output results;
	matrix list results;
	capture confirm matrix resultsall;
	display _rc;
	if _rc>0 {; matrix resultsall=results;};
	if _rc==0 {; matrix resultsall=(resultsall,results);};
	matrix list resultsall;
	* drop restriction;
	drop temprestrict;
end;

* Estimation program with fixed effects rather than including dummy variables;
capture program drop estmodcpsfe;
program define estmodcpsfe;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	* 11: Outcome variable;
	display "Estimation results for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* Summary stats (should make it for positive negative values of treatment variable, problem for intensity);
	* tab hhjobloss_u_m234 if hhjobloss_u_m2_vs_emp==1 & inlist(restrictlev,0,1) & inlist(yfdic,${yearsall}) & inlist(start_seq,${seqbeg}) & hunbankshtr!=.;
	tabstat `11' ///
	    if temprestrict==1 ///
		, by(`10') stat(n mean) col(statistics) save;
	ret li;
	matrix stat0=r(Stat1);
	matrix stat1=r(Stat2);
	matrix totals=r(StatTotal);
	matrix stats=(totals,stat1,stat0)';
	matrix results=(stats[.,1..1]\stats[.,2..2]);
	matrix rownames results = "Sample N" "Treat N" "Control N" "Sample mean" "Treat mean" "Control mean";
	matrix colnames results = "`9'";
	matrix list results;
	* No controls regression;
	xtreg `11' `10' ///
	    if temprestrict==1 ///
		, i(start_mtime) fe robust;
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "OLS noctrl beta pt" "OLS noctrl beta se" "OLS noctrl beta pv";
	matrix results=(results\resultsadd);
	* With controls OLS;
	xtreg `11' `10' ${controlvars} ///
	    if temprestrict==1 ///
		, i(start_mtime) fe robust;
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "OLS wictrl beta pt" "OLS wictrl beta se" "OLS wictrl beta pv";
	matrix results=(results\resultsadd);
	* Output results;
	matrix list results;
	capture confirm matrix resultsall;
	display _rc;
	if _rc>0 {; matrix resultsall=results;};
	if _rc==0 {; matrix resultsall=(resultsall,results);};
	matrix list resultsall;
	* drop restriction;
	drop temprestrict;
end;

* Estimation program using VCE for robust standard errors;
capture program drop estmodcpsvce;
program define estmodcpsvce;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	* 11: Outcome variable;
	display "Estimation results for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* Summary stats (should make it for positive negative values of treatment variable, problem for intensity);
	* tab hhjobloss_u_m234 if hhjobloss_u_m2_vs_emp==1 & inlist(restrictlev,0,1) & inlist(yfdic,${yearsall}) & inlist(start_seq,${seqbeg}) & hunbankshtr!=.;
	tabstat `11' ///
	    if temprestrict==1 ///
		, by(`10') stat(n mean) col(statistics) save;
	ret li;
	matrix stat0=r(Stat1);
	matrix stat1=r(Stat2);
	matrix totals=r(StatTotal);
	matrix stats=(totals,stat1,stat0)';
	matrix results=(stats[.,1..1]\stats[.,2..2]);
	matrix rownames results = "Sample N" "Treat N" "Control N" "Sample mean" "Treat mean" "Control mean";
	matrix colnames results = "`9'";
	matrix list results;
	* No controls regression;
	reg `11' `10' ${controlvarstime} ///
	    if temprestrict==1 ///
		, vce(robust);
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "OLS noctrl beta pt" "OLS noctrl beta se" "OLS noctrl beta pv";
	matrix results=(results\resultsadd);
	* With controls OLS;
	reg `11' `10' ${controlvars} ${controlvarstime} ///
	    if temprestrict==1 ///
		, vce(robust);
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "OLS wictrl beta pt" "OLS wictrl beta se" "OLS wictrl beta pv";
	matrix results=(results\resultsadd);
	* Output results;
	matrix list results;
	capture confirm matrix resultsall;
	display _rc;
	if _rc>0 {; matrix resultsall=results;};
	if _rc==0 {; matrix resultsall=(resultsall,results);};
	matrix list resultsall;
	* drop restriction;
	drop temprestrict;
end;

* PSA Oster 2019 command;
* http://fmwww.bc.edu/repec/bocode/s/selection.pdf
* https://ideas.repec.org/c/boc/bocode/s457677.html;
capture program drop estoster;
program define estoster;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	* 11: Outcome variable;
	* 12: Delta;
	display "Estimation results for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* Summary stats;
	tabstat `11' ///
	    if temprestrict==1 ///
		, by(`10') stat(n mean) col(statistics) save;
	ret li;
	matrix stat0=r(Stat1);
	matrix stat1=r(Stat2);
	matrix totals=r(StatTotal);
	matrix stats=(totals,stat1,stat0)';
	matrix results=(stats[.,1..1]\stats[.,2..2]);
	matrix rownames results = "Sample N" "Treat N" "Control N" "Sample mean" "Treat mean" "Control mean";
	matrix colnames results = "`9'";
	matrix list results;
	* No controls regression;
	reg `11' `10' ${controlvarstimeinds} ///
	    if temprestrict==1 ///
		, robust;
	matrix est=r(table);
	scalar r2=`e(r2)';
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]\r2);
	matrix rownames resultsadd = "OLS noctrl beta pt" "OLS noctrl beta se" "OLS noctrl beta pv" "OLS noctrl r squar";
	matrix results=(results\resultsadd);
	* With controls OLS;
	reg `11' `10' ${controlvars} ${controlvarstimeinds} ///
	    if temprestrict==1 ///
		, robust;
	matrix est=r(table);
	scalar r2=`e(r2)';
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]\r2);
	matrix rownames resultsadd = "OLS wictrl beta pt" "OLS wictrl beta se" "OLS wictrl beta pv" "OLS wictrl r squar";
	matrix results=(results\resultsadd);
	* Oster analysis;
	* From: https://www.nber.org/system/files/working_papers/w19054/w19054.pdf pi is 2.2;
	* from Oster 2019, pi is 1.3;
	local r2max = min(1,1.3*`e(r2)');
	display "From Oster rmax of `r2', based on rsquared of `e(r2)', for `9'";
	psacalc delta `10', mcontrol(${controlvarstimeinds}) rmax(`r2max');
	local deltastar=`r(delta)';
	psacalc beta `10', mcontrol(${controlvarstimeinds}) delta(`12') rmax(`r2max');
	local delta=`r(delta)';	
	local beta=`r(beta)';
	scalar r2max=`r2max';
	scalar deltastar=`deltastar';
	scalar delta=`delta';
	scalar beta=`beta';
	matrix resultsadd=(r2max\deltastar\delta\beta);
	matrix rownames resultsadd = "Oster 2019 rmaxPi1" "Oster 2019 deltast" "Oster 2019 delta0 " "Oster 2019 betaest";
	matrix results=(results\resultsadd);
	* Output results;
	matrix list results;
	capture confirm matrix resultsall;
	display _rc;
	if _rc>0 {; matrix resultsall=results;};
	if _rc==0 {; matrix resultsall=(resultsall,results);};
	matrix list resultsall;
	* drop restriction;
	drop temprestrict;
end;

* predicted values, relevant for testing assumptions behind linear probability model;
capture program drop linprobpred;
program define linprobpred;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	* 11: Outcome variable;
	display "Linear probability model predictions results for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* With controls OLS (from estmodcps);
	reg `11' `10' ${controlvars} ${controlvarstime} ///
	    if temprestrict==1 ///
		, robust;
	predict `1'pr`11' if temprestrict==1;
	* histogram;
	hist `1'pr`11' if temprestrict==1;
	graph save hist${vnum}_${vers}_`1'pr`11', replace;
	graph export "${projdir}\hist${vnum}_${vers}_`1'pr`11'.pdf", as(pdf) name("Graph") replace;
	graph export "${projdir}\hist${vnum}_${vers}_`1'pr`11'.png", as(png) name("Graph") replace;
	* mean and share positive;
	gen `1'pr`11'ps=0 if temprestrict==1;
	replace `1'pr`11'ps=1 if `1'pr`11'>=0;
	sum `1'pr`11' `1'pr`11'ps if temprestrict==1;
	* drop restriction;
	drop temprestrict;
end;

* Estimation program with Probit instead of linear probability model;
capture program drop estmodcpsprobit;
program define estmodcpsprobit;
	* 1: Outcome restriction variable;
	* 2: Outcome selection value;
	* 3: Explanatory restriction variable;
	* 4: Explanatory selection value;
	* 5: Year restriction variable;
	* 6: Year selection value;
	* 7: Sequence restriction variable;
	* 8: Sequence selection value;
	* 9: Name of output file;
	* 10: Treatment variable;
	* 11: Outcome variable;
	display "Estimation results for `9'";
	* restriction, temporary;
	gen temprestrict=0;
	replace temprestrict=1 if inlist(`1',`2') & inlist(`3',`4') & inlist(`5',`6') & inlist(`7',`8');
	* Summary stats (should make it for positive negative values of treatment variable, problem for intensity);
	* tab hhjobloss_u_m234 if hhjobloss_u_m2_vs_emp==1 & inlist(restrictlev,0,1) & inlist(yfdic,${yearsall}) & inlist(start_seq,${seqbeg}) & hunbankshtr!=.;
	tabstat `11' ///
	    if temprestrict==1 ///
		, by(`10') stat(n mean) col(statistics) save;
	ret li;
	matrix stat0=r(Stat1);
	matrix stat1=r(Stat2);
	matrix totals=r(StatTotal);
	matrix stats=(totals,stat1,stat0)';
	matrix results=(stats[.,1..1]\stats[.,2..2]);
	matrix rownames results = "Sample N" "Treat N" "Control N" "Sample mean" "Treat mean" "Control mean";
	matrix colnames results = "`9'";
	matrix list results;
	* No controls Probit;
	probit `11' `10' ${controlvarstime} ///
	    if temprestrict==1 ///
		, robust;
	estimates store probitest;
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "Pro noctrl beta pt" "Pro noctrl beta se" "Pro noctrl beta pv";
	matrix results=(results\resultsadd);
	* margins and stored results, show with and without treatment (display treated first);
	margins, at(`10'=(0 1)) atmeans post;
	matrix margtable=r(table);
	matrix list margtable;
	matrix resultsadd=(margtable[1,2]\margtable[2,2]\margtable[1,1]\margtable[2,1]);
	matrix rownames resultsadd = "Pro noctrl trt1 pt" "Pro noctrl trt1 se" "Pro noctrl trt0 pt" "Pro noctrl trt0 se";
	matrix results=(results\resultsadd);
	* margins difference;
	estimates restore probitest;
	margins, at(`10'=(0 1)) atmeans contrast(atcontrast(r._at) wald) post;
	matrix margdiffb=r(b);
	matrix margdiffV=r(V);
	matrix margdiffse=(margdiffV[1,1])^0.5;
	matrix margdiffchisq=r(chi2);
	matrix margdiffp=r(p);
	matrix resultsadd=(margdiffb[1,1]\margdiffse[1,1]\margdiffchisq[1,1]\margdiffp[1,1]);
	matrix rownames resultsadd = "Pro noctrl diff pt" "Pro noctrl diff se" "Pro noctrl diff ch" "Pro noctrl diff pv";
	matrix results=(results\resultsadd);
	* With controls Probit;
	probit `11' `10' ${controlvars} ${controlvarstime} ///
	    if temprestrict==1 ///
		, robust;
	estimates store probitest;
	matrix est=r(table);
	matrix resultsadd=(est[1,1..1]\est[2,1..1]\est[4,1..1]);
	matrix rownames resultsadd = "Pro wictrl beta pt" "Pro wictrl beta se" "Pro wictrl beta pv";
	matrix results=(results\resultsadd);
	* margins and stored results, show with and without treatment (display treated first);
	margins, at(`10'=(0 1)) atmeans post;
	matrix margtable=r(table);
	matrix list margtable;
	matrix resultsadd=(margtable[1,2]\margtable[2,2]\margtable[1,1]\margtable[2,1]);
	matrix rownames resultsadd = "Pro wictrl trt1 pt" "Pro wictrl trt1 se" "Pro wictrl trt0 pt" "Pro wictrl trt0 se";
	matrix results=(results\resultsadd);
	* margins difference;
	estimates restore probitest;
	margins, at(`10'=(0 1)) atmeans contrast(atcontrast(r._at) wald) post;
	matrix margdiffb=r(b);
	matrix margdiffV=r(V);
	matrix margdiffse=(margdiffV[1,1])^0.5;
	matrix margdiffchisq=r(chi2);
	matrix margdiffp=r(p);
	matrix resultsadd=(margdiffb[1,1]\margdiffse[1,1]\margdiffchisq[1,1]\margdiffp[1,1]);
	matrix rownames resultsadd = "Pro wictrl diff pt" "Pro wictrl diff se" "Pro wictrl diff ch" "Pro wictrl diff pv";
	matrix results=(results\resultsadd);
	* Output results;
	matrix list results;
	capture confirm matrix resultsall;
	display _rc;
	if _rc>0 {; matrix resultsall=results;};
	if _rc==0 {; matrix resultsall=(resultsall,results);};
	matrix list resultsall;
	estimates drop probitest;
	* drop restriction;
	drop temprestrict;
end;

* END OF PROGRAMS *;
